<?php

function siteorigin_widgets_icons_fontawesome_filter( $icons ){
	return array_merge($icons, array(
		'500px' => array( 'unicode' => '&#xf26e;', 'styles' => array( 'sow-fab' ), ),
		'accessible-icon' => array( 'unicode' => '&#xf368;', 'styles' => array( 'sow-fab' ), ),
		'accusoft' => array( 'unicode' => '&#xf369;', 'styles' => array( 'sow-fab' ), ),
		'acquisitions-incorporated' => array( 'unicode' => '&#xf6af;', 'styles' => array( 'sow-fab' ), ),
		'ad' => array( 'unicode' => '&#xf641;', 'styles' => array( 'sow-fas' ), ),
		'address-book' => array( 'unicode' => '&#xf2b9;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'address-card' => array( 'unicode' => '&#xf2bb;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'adjust' => array( 'unicode' => '&#xf042;', 'styles' => array( 'sow-fas' ), ),
		'adn' => array( 'unicode' => '&#xf170;', 'styles' => array( 'sow-fab' ), ),
		'adversal' => array( 'unicode' => '&#xf36a;', 'styles' => array( 'sow-fab' ), ),
		'affiliatetheme' => array( 'unicode' => '&#xf36b;', 'styles' => array( 'sow-fab' ), ),
		'air-freshener' => array( 'unicode' => '&#xf5d0;', 'styles' => array( 'sow-fas' ), ),
		'airbnb' => array( 'unicode' => '&#xf834;', 'styles' => array( 'sow-fab' ), ),
		'algolia' => array( 'unicode' => '&#xf36c;', 'styles' => array( 'sow-fab' ), ),
		'align-center' => array( 'unicode' => '&#xf037;', 'styles' => array( 'sow-fas' ), ),
		'align-justify' => array( 'unicode' => '&#xf039;', 'styles' => array( 'sow-fas' ), ),
		'align-left' => array( 'unicode' => '&#xf036;', 'styles' => array( 'sow-fas' ), ),
		'align-right' => array( 'unicode' => '&#xf038;', 'styles' => array( 'sow-fas' ), ),
		'alipay' => array( 'unicode' => '&#xf642;', 'styles' => array( 'sow-fab' ), ),
		'allergies' => array( 'unicode' => '&#xf461;', 'styles' => array( 'sow-fas' ), ),
		'amazon' => array( 'unicode' => '&#xf270;', 'styles' => array( 'sow-fab' ), ),
		'amazon-pay' => array( 'unicode' => '&#xf42c;', 'styles' => array( 'sow-fab' ), ),
		'ambulance' => array( 'unicode' => '&#xf0f9;', 'styles' => array( 'sow-fas' ), ),
		'american-sign-language-interpreting' => array( 'unicode' => '&#xf2a3;', 'styles' => array( 'sow-fas' ), ),
		'amilia' => array( 'unicode' => '&#xf36d;', 'styles' => array( 'sow-fab' ), ),
		'anchor' => array( 'unicode' => '&#xf13d;', 'styles' => array( 'sow-fas' ), ),
		'android' => array( 'unicode' => '&#xf17b;', 'styles' => array( 'sow-fab' ), ),
		'angellist' => array( 'unicode' => '&#xf209;', 'styles' => array( 'sow-fab' ), ),
		'angle-double-down' => array( 'unicode' => '&#xf103;', 'styles' => array( 'sow-fas' ), ),
		'angle-double-left' => array( 'unicode' => '&#xf100;', 'styles' => array( 'sow-fas' ), ),
		'angle-double-right' => array( 'unicode' => '&#xf101;', 'styles' => array( 'sow-fas' ), ),
		'angle-double-up' => array( 'unicode' => '&#xf102;', 'styles' => array( 'sow-fas' ), ),
		'angle-down' => array( 'unicode' => '&#xf107;', 'styles' => array( 'sow-fas' ), ),
		'angle-left' => array( 'unicode' => '&#xf104;', 'styles' => array( 'sow-fas' ), ),
		'angle-right' => array( 'unicode' => '&#xf105;', 'styles' => array( 'sow-fas' ), ),
		'angle-up' => array( 'unicode' => '&#xf106;', 'styles' => array( 'sow-fas' ), ),
		'angry' => array( 'unicode' => '&#xf556;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'angrycreative' => array( 'unicode' => '&#xf36e;', 'styles' => array( 'sow-fab' ), ),
		'angular' => array( 'unicode' => '&#xf420;', 'styles' => array( 'sow-fab' ), ),
		'ankh' => array( 'unicode' => '&#xf644;', 'styles' => array( 'sow-fas' ), ),
		'app-store' => array( 'unicode' => '&#xf36f;', 'styles' => array( 'sow-fab' ), ),
		'app-store-ios' => array( 'unicode' => '&#xf370;', 'styles' => array( 'sow-fab' ), ),
		'apper' => array( 'unicode' => '&#xf371;', 'styles' => array( 'sow-fab' ), ),
		'apple' => array( 'unicode' => '&#xf179;', 'styles' => array( 'sow-fab' ), ),
		'apple-alt' => array( 'unicode' => '&#xf5d1;', 'styles' => array( 'sow-fas' ), ),
		'apple-pay' => array( 'unicode' => '&#xf415;', 'styles' => array( 'sow-fab' ), ),
		'archive' => array( 'unicode' => '&#xf187;', 'styles' => array( 'sow-fas' ), ),
		'archway' => array( 'unicode' => '&#xf557;', 'styles' => array( 'sow-fas' ), ),
		'arrow-alt-circle-down' => array( 'unicode' => '&#xf358;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'arrow-alt-circle-left' => array( 'unicode' => '&#xf359;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'arrow-alt-circle-right' => array( 'unicode' => '&#xf35a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'arrow-alt-circle-up' => array( 'unicode' => '&#xf35b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'arrow-circle-down' => array( 'unicode' => '&#xf0ab;', 'styles' => array( 'sow-fas' ), ),
		'arrow-circle-left' => array( 'unicode' => '&#xf0a8;', 'styles' => array( 'sow-fas' ), ),
		'arrow-circle-right' => array( 'unicode' => '&#xf0a9;', 'styles' => array( 'sow-fas' ), ),
		'arrow-circle-up' => array( 'unicode' => '&#xf0aa;', 'styles' => array( 'sow-fas' ), ),
		'arrow-down' => array( 'unicode' => '&#xf063;', 'styles' => array( 'sow-fas' ), ),
		'arrow-left' => array( 'unicode' => '&#xf060;', 'styles' => array( 'sow-fas' ), ),
		'arrow-right' => array( 'unicode' => '&#xf061;', 'styles' => array( 'sow-fas' ), ),
		'arrow-up' => array( 'unicode' => '&#xf062;', 'styles' => array( 'sow-fas' ), ),
		'arrows-alt' => array( 'unicode' => '&#xf0b2;', 'styles' => array( 'sow-fas' ), ),
		'arrows-alt-h' => array( 'unicode' => '&#xf337;', 'styles' => array( 'sow-fas' ), ),
		'arrows-alt-v' => array( 'unicode' => '&#xf338;', 'styles' => array( 'sow-fas' ), ),
		'artstation' => array( 'unicode' => '&#xf77a;', 'styles' => array( 'sow-fab' ), ),
		'assistive-listening-systems' => array( 'unicode' => '&#xf2a2;', 'styles' => array( 'sow-fas' ), ),
		'asterisk' => array( 'unicode' => '&#xf069;', 'styles' => array( 'sow-fas' ), ),
		'asymmetrik' => array( 'unicode' => '&#xf372;', 'styles' => array( 'sow-fab' ), ),
		'at' => array( 'unicode' => '&#xf1fa;', 'styles' => array( 'sow-fas' ), ),
		'atlas' => array( 'unicode' => '&#xf558;', 'styles' => array( 'sow-fas' ), ),
		'atlassian' => array( 'unicode' => '&#xf77b;', 'styles' => array( 'sow-fab' ), ),
		'atom' => array( 'unicode' => '&#xf5d2;', 'styles' => array( 'sow-fas' ), ),
		'audible' => array( 'unicode' => '&#xf373;', 'styles' => array( 'sow-fab' ), ),
		'audio-description' => array( 'unicode' => '&#xf29e;', 'styles' => array( 'sow-fas' ), ),
		'autoprefixer' => array( 'unicode' => '&#xf41c;', 'styles' => array( 'sow-fab' ), ),
		'avianex' => array( 'unicode' => '&#xf374;', 'styles' => array( 'sow-fab' ), ),
		'aviato' => array( 'unicode' => '&#xf421;', 'styles' => array( 'sow-fab' ), ),
		'award' => array( 'unicode' => '&#xf559;', 'styles' => array( 'sow-fas' ), ),
		'aws' => array( 'unicode' => '&#xf375;', 'styles' => array( 'sow-fab' ), ),
		'baby' => array( 'unicode' => '&#xf77c;', 'styles' => array( 'sow-fas' ), ),
		'baby-carriage' => array( 'unicode' => '&#xf77d;', 'styles' => array( 'sow-fas' ), ),
		'backspace' => array( 'unicode' => '&#xf55a;', 'styles' => array( 'sow-fas' ), ),
		'backward' => array( 'unicode' => '&#xf04a;', 'styles' => array( 'sow-fas' ), ),
		'bacon' => array( 'unicode' => '&#xf7e5;', 'styles' => array( 'sow-fas' ), ),
		'bacteria' => array( 'unicode' => '&#xe059;', 'styles' => array( 'sow-fas' ), ),
		'bacterium' => array( 'unicode' => '&#xe05a;', 'styles' => array( 'sow-fas' ), ),
		'bahai' => array( 'unicode' => '&#xf666;', 'styles' => array( 'sow-fas' ), ),
		'balance-scale' => array( 'unicode' => '&#xf24e;', 'styles' => array( 'sow-fas' ), ),
		'balance-scale-left' => array( 'unicode' => '&#xf515;', 'styles' => array( 'sow-fas' ), ),
		'balance-scale-right' => array( 'unicode' => '&#xf516;', 'styles' => array( 'sow-fas' ), ),
		'ban' => array( 'unicode' => '&#xf05e;', 'styles' => array( 'sow-fas' ), ),
		'band-aid' => array( 'unicode' => '&#xf462;', 'styles' => array( 'sow-fas' ), ),
		'bandcamp' => array( 'unicode' => '&#xf2d5;', 'styles' => array( 'sow-fab' ), ),
		'barcode' => array( 'unicode' => '&#xf02a;', 'styles' => array( 'sow-fas' ), ),
		'bars' => array( 'unicode' => '&#xf0c9;', 'styles' => array( 'sow-fas' ), ),
		'baseball-ball' => array( 'unicode' => '&#xf433;', 'styles' => array( 'sow-fas' ), ),
		'basketball-ball' => array( 'unicode' => '&#xf434;', 'styles' => array( 'sow-fas' ), ),
		'bath' => array( 'unicode' => '&#xf2cd;', 'styles' => array( 'sow-fas' ), ),
		'battery-empty' => array( 'unicode' => '&#xf244;', 'styles' => array( 'sow-fas' ), ),
		'battery-full' => array( 'unicode' => '&#xf240;', 'styles' => array( 'sow-fas' ), ),
		'battery-half' => array( 'unicode' => '&#xf242;', 'styles' => array( 'sow-fas' ), ),
		'battery-quarter' => array( 'unicode' => '&#xf243;', 'styles' => array( 'sow-fas' ), ),
		'battery-three-quarters' => array( 'unicode' => '&#xf241;', 'styles' => array( 'sow-fas' ), ),
		'battle-net' => array( 'unicode' => '&#xf835;', 'styles' => array( 'sow-fab' ), ),
		'bed' => array( 'unicode' => '&#xf236;', 'styles' => array( 'sow-fas' ), ),
		'beer' => array( 'unicode' => '&#xf0fc;', 'styles' => array( 'sow-fas' ), ),
		'behance' => array( 'unicode' => '&#xf1b4;', 'styles' => array( 'sow-fab' ), ),
		'behance-square' => array( 'unicode' => '&#xf1b5;', 'styles' => array( 'sow-fab' ), ),
		'bell' => array( 'unicode' => '&#xf0f3;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'bell-slash' => array( 'unicode' => '&#xf1f6;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'bezier-curve' => array( 'unicode' => '&#xf55b;', 'styles' => array( 'sow-fas' ), ),
		'bible' => array( 'unicode' => '&#xf647;', 'styles' => array( 'sow-fas' ), ),
		'bicycle' => array( 'unicode' => '&#xf206;', 'styles' => array( 'sow-fas' ), ),
		'biking' => array( 'unicode' => '&#xf84a;', 'styles' => array( 'sow-fas' ), ),
		'bimobject' => array( 'unicode' => '&#xf378;', 'styles' => array( 'sow-fab' ), ),
		'binoculars' => array( 'unicode' => '&#xf1e5;', 'styles' => array( 'sow-fas' ), ),
		'biohazard' => array( 'unicode' => '&#xf780;', 'styles' => array( 'sow-fas' ), ),
		'birthday-cake' => array( 'unicode' => '&#xf1fd;', 'styles' => array( 'sow-fas' ), ),
		'bitbucket' => array( 'unicode' => '&#xf171;', 'styles' => array( 'sow-fab' ), ),
		'bitcoin' => array( 'unicode' => '&#xf379;', 'styles' => array( 'sow-fab' ), ),
		'bity' => array( 'unicode' => '&#xf37a;', 'styles' => array( 'sow-fab' ), ),
		'black-tie' => array( 'unicode' => '&#xf27e;', 'styles' => array( 'sow-fab' ), ),
		'blackberry' => array( 'unicode' => '&#xf37b;', 'styles' => array( 'sow-fab' ), ),
		'blender' => array( 'unicode' => '&#xf517;', 'styles' => array( 'sow-fas' ), ),
		'blender-phone' => array( 'unicode' => '&#xf6b6;', 'styles' => array( 'sow-fas' ), ),
		'blind' => array( 'unicode' => '&#xf29d;', 'styles' => array( 'sow-fas' ), ),
		'blog' => array( 'unicode' => '&#xf781;', 'styles' => array( 'sow-fas' ), ),
		'blogger' => array( 'unicode' => '&#xf37c;', 'styles' => array( 'sow-fab' ), ),
		'blogger-b' => array( 'unicode' => '&#xf37d;', 'styles' => array( 'sow-fab' ), ),
		'bluetooth' => array( 'unicode' => '&#xf293;', 'styles' => array( 'sow-fab' ), ),
		'bluetooth-b' => array( 'unicode' => '&#xf294;', 'styles' => array( 'sow-fab' ), ),
		'bold' => array( 'unicode' => '&#xf032;', 'styles' => array( 'sow-fas' ), ),
		'bolt' => array( 'unicode' => '&#xf0e7;', 'styles' => array( 'sow-fas' ), ),
		'bomb' => array( 'unicode' => '&#xf1e2;', 'styles' => array( 'sow-fas' ), ),
		'bone' => array( 'unicode' => '&#xf5d7;', 'styles' => array( 'sow-fas' ), ),
		'bong' => array( 'unicode' => '&#xf55c;', 'styles' => array( 'sow-fas' ), ),
		'book' => array( 'unicode' => '&#xf02d;', 'styles' => array( 'sow-fas' ), ),
		'book-dead' => array( 'unicode' => '&#xf6b7;', 'styles' => array( 'sow-fas' ), ),
		'book-medical' => array( 'unicode' => '&#xf7e6;', 'styles' => array( 'sow-fas' ), ),
		'book-open' => array( 'unicode' => '&#xf518;', 'styles' => array( 'sow-fas' ), ),
		'book-reader' => array( 'unicode' => '&#xf5da;', 'styles' => array( 'sow-fas' ), ),
		'bookmark' => array( 'unicode' => '&#xf02e;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'bootstrap' => array( 'unicode' => '&#xf836;', 'styles' => array( 'sow-fab' ), ),
		'border-all' => array( 'unicode' => '&#xf84c;', 'styles' => array( 'sow-fas' ), ),
		'border-none' => array( 'unicode' => '&#xf850;', 'styles' => array( 'sow-fas' ), ),
		'border-style' => array( 'unicode' => '&#xf853;', 'styles' => array( 'sow-fas' ), ),
		'bowling-ball' => array( 'unicode' => '&#xf436;', 'styles' => array( 'sow-fas' ), ),
		'box' => array( 'unicode' => '&#xf466;', 'styles' => array( 'sow-fas' ), ),
		'box-open' => array( 'unicode' => '&#xf49e;', 'styles' => array( 'sow-fas' ), ),
		'box-tissue' => array( 'unicode' => '&#xe05b;', 'styles' => array( 'sow-fas' ), ),
		'boxes' => array( 'unicode' => '&#xf468;', 'styles' => array( 'sow-fas' ), ),
		'braille' => array( 'unicode' => '&#xf2a1;', 'styles' => array( 'sow-fas' ), ),
		'brain' => array( 'unicode' => '&#xf5dc;', 'styles' => array( 'sow-fas' ), ),
		'bread-slice' => array( 'unicode' => '&#xf7ec;', 'styles' => array( 'sow-fas' ), ),
		'briefcase' => array( 'unicode' => '&#xf0b1;', 'styles' => array( 'sow-fas' ), ),
		'briefcase-medical' => array( 'unicode' => '&#xf469;', 'styles' => array( 'sow-fas' ), ),
		'broadcast-tower' => array( 'unicode' => '&#xf519;', 'styles' => array( 'sow-fas' ), ),
		'broom' => array( 'unicode' => '&#xf51a;', 'styles' => array( 'sow-fas' ), ),
		'brush' => array( 'unicode' => '&#xf55d;', 'styles' => array( 'sow-fas' ), ),
		'btc' => array( 'unicode' => '&#xf15a;', 'styles' => array( 'sow-fab' ), ),
		'buffer' => array( 'unicode' => '&#xf837;', 'styles' => array( 'sow-fab' ), ),
		'bug' => array( 'unicode' => '&#xf188;', 'styles' => array( 'sow-fas' ), ),
		'building' => array( 'unicode' => '&#xf1ad;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'bullhorn' => array( 'unicode' => '&#xf0a1;', 'styles' => array( 'sow-fas' ), ),
		'bullseye' => array( 'unicode' => '&#xf140;', 'styles' => array( 'sow-fas' ), ),
		'burn' => array( 'unicode' => '&#xf46a;', 'styles' => array( 'sow-fas' ), ),
		'buromobelexperte' => array( 'unicode' => '&#xf37f;', 'styles' => array( 'sow-fab' ), ),
		'bus' => array( 'unicode' => '&#xf207;', 'styles' => array( 'sow-fas' ), ),
		'bus-alt' => array( 'unicode' => '&#xf55e;', 'styles' => array( 'sow-fas' ), ),
		'business-time' => array( 'unicode' => '&#xf64a;', 'styles' => array( 'sow-fas' ), ),
		'buy-n-large' => array( 'unicode' => '&#xf8a6;', 'styles' => array( 'sow-fab' ), ),
		'buysellads' => array( 'unicode' => '&#xf20d;', 'styles' => array( 'sow-fab' ), ),
		'calculator' => array( 'unicode' => '&#xf1ec;', 'styles' => array( 'sow-fas' ), ),
		'calendar' => array( 'unicode' => '&#xf133;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-alt' => array( 'unicode' => '&#xf073;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-check' => array( 'unicode' => '&#xf274;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-day' => array( 'unicode' => '&#xf783;', 'styles' => array( 'sow-fas' ), ),
		'calendar-minus' => array( 'unicode' => '&#xf272;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-plus' => array( 'unicode' => '&#xf271;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-times' => array( 'unicode' => '&#xf273;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'calendar-week' => array( 'unicode' => '&#xf784;', 'styles' => array( 'sow-fas' ), ),
		'camera' => array( 'unicode' => '&#xf030;', 'styles' => array( 'sow-fas' ), ),
		'camera-retro' => array( 'unicode' => '&#xf083;', 'styles' => array( 'sow-fas' ), ),
		'campground' => array( 'unicode' => '&#xf6bb;', 'styles' => array( 'sow-fas' ), ),
		'canadian-maple-leaf' => array( 'unicode' => '&#xf785;', 'styles' => array( 'sow-fab' ), ),
		'candy-cane' => array( 'unicode' => '&#xf786;', 'styles' => array( 'sow-fas' ), ),
		'cannabis' => array( 'unicode' => '&#xf55f;', 'styles' => array( 'sow-fas' ), ),
		'capsules' => array( 'unicode' => '&#xf46b;', 'styles' => array( 'sow-fas' ), ),
		'car' => array( 'unicode' => '&#xf1b9;', 'styles' => array( 'sow-fas' ), ),
		'car-alt' => array( 'unicode' => '&#xf5de;', 'styles' => array( 'sow-fas' ), ),
		'car-battery' => array( 'unicode' => '&#xf5df;', 'styles' => array( 'sow-fas' ), ),
		'car-crash' => array( 'unicode' => '&#xf5e1;', 'styles' => array( 'sow-fas' ), ),
		'car-side' => array( 'unicode' => '&#xf5e4;', 'styles' => array( 'sow-fas' ), ),
		'caravan' => array( 'unicode' => '&#xf8ff;', 'styles' => array( 'sow-fas' ), ),
		'caret-down' => array( 'unicode' => '&#xf0d7;', 'styles' => array( 'sow-fas' ), ),
		'caret-left' => array( 'unicode' => '&#xf0d9;', 'styles' => array( 'sow-fas' ), ),
		'caret-right' => array( 'unicode' => '&#xf0da;', 'styles' => array( 'sow-fas' ), ),
		'caret-square-down' => array( 'unicode' => '&#xf150;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'caret-square-left' => array( 'unicode' => '&#xf191;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'caret-square-right' => array( 'unicode' => '&#xf152;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'caret-square-up' => array( 'unicode' => '&#xf151;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'caret-up' => array( 'unicode' => '&#xf0d8;', 'styles' => array( 'sow-fas' ), ),
		'carrot' => array( 'unicode' => '&#xf787;', 'styles' => array( 'sow-fas' ), ),
		'cart-arrow-down' => array( 'unicode' => '&#xf218;', 'styles' => array( 'sow-fas' ), ),
		'cart-plus' => array( 'unicode' => '&#xf217;', 'styles' => array( 'sow-fas' ), ),
		'cash-register' => array( 'unicode' => '&#xf788;', 'styles' => array( 'sow-fas' ), ),
		'cat' => array( 'unicode' => '&#xf6be;', 'styles' => array( 'sow-fas' ), ),
		'cc-amazon-pay' => array( 'unicode' => '&#xf42d;', 'styles' => array( 'sow-fab' ), ),
		'cc-amex' => array( 'unicode' => '&#xf1f3;', 'styles' => array( 'sow-fab' ), ),
		'cc-apple-pay' => array( 'unicode' => '&#xf416;', 'styles' => array( 'sow-fab' ), ),
		'cc-diners-club' => array( 'unicode' => '&#xf24c;', 'styles' => array( 'sow-fab' ), ),
		'cc-discover' => array( 'unicode' => '&#xf1f2;', 'styles' => array( 'sow-fab' ), ),
		'cc-jcb' => array( 'unicode' => '&#xf24b;', 'styles' => array( 'sow-fab' ), ),
		'cc-mastercard' => array( 'unicode' => '&#xf1f1;', 'styles' => array( 'sow-fab' ), ),
		'cc-paypal' => array( 'unicode' => '&#xf1f4;', 'styles' => array( 'sow-fab' ), ),
		'cc-stripe' => array( 'unicode' => '&#xf1f5;', 'styles' => array( 'sow-fab' ), ),
		'cc-visa' => array( 'unicode' => '&#xf1f0;', 'styles' => array( 'sow-fab' ), ),
		'centercode' => array( 'unicode' => '&#xf380;', 'styles' => array( 'sow-fab' ), ),
		'centos' => array( 'unicode' => '&#xf789;', 'styles' => array( 'sow-fab' ), ),
		'certificate' => array( 'unicode' => '&#xf0a3;', 'styles' => array( 'sow-fas' ), ),
		'chair' => array( 'unicode' => '&#xf6c0;', 'styles' => array( 'sow-fas' ), ),
		'chalkboard' => array( 'unicode' => '&#xf51b;', 'styles' => array( 'sow-fas' ), ),
		'chalkboard-teacher' => array( 'unicode' => '&#xf51c;', 'styles' => array( 'sow-fas' ), ),
		'charging-station' => array( 'unicode' => '&#xf5e7;', 'styles' => array( 'sow-fas' ), ),
		'chart-area' => array( 'unicode' => '&#xf1fe;', 'styles' => array( 'sow-fas' ), ),
		'chart-bar' => array( 'unicode' => '&#xf080;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'chart-line' => array( 'unicode' => '&#xf201;', 'styles' => array( 'sow-fas' ), ),
		'chart-pie' => array( 'unicode' => '&#xf200;', 'styles' => array( 'sow-fas' ), ),
		'check' => array( 'unicode' => '&#xf00c;', 'styles' => array( 'sow-fas' ), ),
		'check-circle' => array( 'unicode' => '&#xf058;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'check-double' => array( 'unicode' => '&#xf560;', 'styles' => array( 'sow-fas' ), ),
		'check-square' => array( 'unicode' => '&#xf14a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'cheese' => array( 'unicode' => '&#xf7ef;', 'styles' => array( 'sow-fas' ), ),
		'chess' => array( 'unicode' => '&#xf439;', 'styles' => array( 'sow-fas' ), ),
		'chess-bishop' => array( 'unicode' => '&#xf43a;', 'styles' => array( 'sow-fas' ), ),
		'chess-board' => array( 'unicode' => '&#xf43c;', 'styles' => array( 'sow-fas' ), ),
		'chess-king' => array( 'unicode' => '&#xf43f;', 'styles' => array( 'sow-fas' ), ),
		'chess-knight' => array( 'unicode' => '&#xf441;', 'styles' => array( 'sow-fas' ), ),
		'chess-pawn' => array( 'unicode' => '&#xf443;', 'styles' => array( 'sow-fas' ), ),
		'chess-queen' => array( 'unicode' => '&#xf445;', 'styles' => array( 'sow-fas' ), ),
		'chess-rook' => array( 'unicode' => '&#xf447;', 'styles' => array( 'sow-fas' ), ),
		'chevron-circle-down' => array( 'unicode' => '&#xf13a;', 'styles' => array( 'sow-fas' ), ),
		'chevron-circle-left' => array( 'unicode' => '&#xf137;', 'styles' => array( 'sow-fas' ), ),
		'chevron-circle-right' => array( 'unicode' => '&#xf138;', 'styles' => array( 'sow-fas' ), ),
		'chevron-circle-up' => array( 'unicode' => '&#xf139;', 'styles' => array( 'sow-fas' ), ),
		'chevron-down' => array( 'unicode' => '&#xf078;', 'styles' => array( 'sow-fas' ), ),
		'chevron-left' => array( 'unicode' => '&#xf053;', 'styles' => array( 'sow-fas' ), ),
		'chevron-right' => array( 'unicode' => '&#xf054;', 'styles' => array( 'sow-fas' ), ),
		'chevron-up' => array( 'unicode' => '&#xf077;', 'styles' => array( 'sow-fas' ), ),
		'child' => array( 'unicode' => '&#xf1ae;', 'styles' => array( 'sow-fas' ), ),
		'chrome' => array( 'unicode' => '&#xf268;', 'styles' => array( 'sow-fab' ), ),
		'chromecast' => array( 'unicode' => '&#xf838;', 'styles' => array( 'sow-fab' ), ),
		'church' => array( 'unicode' => '&#xf51d;', 'styles' => array( 'sow-fas' ), ),
		'circle' => array( 'unicode' => '&#xf111;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'circle-notch' => array( 'unicode' => '&#xf1ce;', 'styles' => array( 'sow-fas' ), ),
		'city' => array( 'unicode' => '&#xf64f;', 'styles' => array( 'sow-fas' ), ),
		'clinic-medical' => array( 'unicode' => '&#xf7f2;', 'styles' => array( 'sow-fas' ), ),
		'clipboard' => array( 'unicode' => '&#xf328;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'clipboard-check' => array( 'unicode' => '&#xf46c;', 'styles' => array( 'sow-fas' ), ),
		'clipboard-list' => array( 'unicode' => '&#xf46d;', 'styles' => array( 'sow-fas' ), ),
		'clock' => array( 'unicode' => '&#xf017;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'clone' => array( 'unicode' => '&#xf24d;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'closed-captioning' => array( 'unicode' => '&#xf20a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'cloud' => array( 'unicode' => '&#xf0c2;', 'styles' => array( 'sow-fas' ), ),
		'cloud-download-alt' => array( 'unicode' => '&#xf381;', 'styles' => array( 'sow-fas' ), ),
		'cloud-meatball' => array( 'unicode' => '&#xf73b;', 'styles' => array( 'sow-fas' ), ),
		'cloud-moon' => array( 'unicode' => '&#xf6c3;', 'styles' => array( 'sow-fas' ), ),
		'cloud-moon-rain' => array( 'unicode' => '&#xf73c;', 'styles' => array( 'sow-fas' ), ),
		'cloud-rain' => array( 'unicode' => '&#xf73d;', 'styles' => array( 'sow-fas' ), ),
		'cloud-showers-heavy' => array( 'unicode' => '&#xf740;', 'styles' => array( 'sow-fas' ), ),
		'cloud-sun' => array( 'unicode' => '&#xf6c4;', 'styles' => array( 'sow-fas' ), ),
		'cloud-sun-rain' => array( 'unicode' => '&#xf743;', 'styles' => array( 'sow-fas' ), ),
		'cloud-upload-alt' => array( 'unicode' => '&#xf382;', 'styles' => array( 'sow-fas' ), ),
		'cloudflare' => array( 'unicode' => '&#xe07d;', 'styles' => array( 'sow-fab' ), ),
		'cloudscale' => array( 'unicode' => '&#xf383;', 'styles' => array( 'sow-fab' ), ),
		'cloudsmith' => array( 'unicode' => '&#xf384;', 'styles' => array( 'sow-fab' ), ),
		'cloudversify' => array( 'unicode' => '&#xf385;', 'styles' => array( 'sow-fab' ), ),
		'cocktail' => array( 'unicode' => '&#xf561;', 'styles' => array( 'sow-fas' ), ),
		'code' => array( 'unicode' => '&#xf121;', 'styles' => array( 'sow-fas' ), ),
		'code-branch' => array( 'unicode' => '&#xf126;', 'styles' => array( 'sow-fas' ), ),
		'codepen' => array( 'unicode' => '&#xf1cb;', 'styles' => array( 'sow-fab' ), ),
		'codiepie' => array( 'unicode' => '&#xf284;', 'styles' => array( 'sow-fab' ), ),
		'coffee' => array( 'unicode' => '&#xf0f4;', 'styles' => array( 'sow-fas' ), ),
		'cog' => array( 'unicode' => '&#xf013;', 'styles' => array( 'sow-fas' ), ),
		'cogs' => array( 'unicode' => '&#xf085;', 'styles' => array( 'sow-fas' ), ),
		'coins' => array( 'unicode' => '&#xf51e;', 'styles' => array( 'sow-fas' ), ),
		'columns' => array( 'unicode' => '&#xf0db;', 'styles' => array( 'sow-fas' ), ),
		'comment' => array( 'unicode' => '&#xf075;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'comment-alt' => array( 'unicode' => '&#xf27a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'comment-dollar' => array( 'unicode' => '&#xf651;', 'styles' => array( 'sow-fas' ), ),
		'comment-dots' => array( 'unicode' => '&#xf4ad;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'comment-medical' => array( 'unicode' => '&#xf7f5;', 'styles' => array( 'sow-fas' ), ),
		'comment-slash' => array( 'unicode' => '&#xf4b3;', 'styles' => array( 'sow-fas' ), ),
		'comments' => array( 'unicode' => '&#xf086;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'comments-dollar' => array( 'unicode' => '&#xf653;', 'styles' => array( 'sow-fas' ), ),
		'compact-disc' => array( 'unicode' => '&#xf51f;', 'styles' => array( 'sow-fas' ), ),
		'compass' => array( 'unicode' => '&#xf14e;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'compress' => array( 'unicode' => '&#xf066;', 'styles' => array( 'sow-fas' ), ),
		'compress-alt' => array( 'unicode' => '&#xf422;', 'styles' => array( 'sow-fas' ), ),
		'compress-arrows-alt' => array( 'unicode' => '&#xf78c;', 'styles' => array( 'sow-fas' ), ),
		'concierge-bell' => array( 'unicode' => '&#xf562;', 'styles' => array( 'sow-fas' ), ),
		'confluence' => array( 'unicode' => '&#xf78d;', 'styles' => array( 'sow-fab' ), ),
		'connectdevelop' => array( 'unicode' => '&#xf20e;', 'styles' => array( 'sow-fab' ), ),
		'contao' => array( 'unicode' => '&#xf26d;', 'styles' => array( 'sow-fab' ), ),
		'cookie' => array( 'unicode' => '&#xf563;', 'styles' => array( 'sow-fas' ), ),
		'cookie-bite' => array( 'unicode' => '&#xf564;', 'styles' => array( 'sow-fas' ), ),
		'copy' => array( 'unicode' => '&#xf0c5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'copyright' => array( 'unicode' => '&#xf1f9;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'cotton-bureau' => array( 'unicode' => '&#xf89e;', 'styles' => array( 'sow-fab' ), ),
		'couch' => array( 'unicode' => '&#xf4b8;', 'styles' => array( 'sow-fas' ), ),
		'cpanel' => array( 'unicode' => '&#xf388;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons' => array( 'unicode' => '&#xf25e;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-by' => array( 'unicode' => '&#xf4e7;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-nc' => array( 'unicode' => '&#xf4e8;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-nc-eu' => array( 'unicode' => '&#xf4e9;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-nc-jp' => array( 'unicode' => '&#xf4ea;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-nd' => array( 'unicode' => '&#xf4eb;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-pd' => array( 'unicode' => '&#xf4ec;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-pd-alt' => array( 'unicode' => '&#xf4ed;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-remix' => array( 'unicode' => '&#xf4ee;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-sa' => array( 'unicode' => '&#xf4ef;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-sampling' => array( 'unicode' => '&#xf4f0;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-sampling-plus' => array( 'unicode' => '&#xf4f1;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-share' => array( 'unicode' => '&#xf4f2;', 'styles' => array( 'sow-fab' ), ),
		'creative-commons-zero' => array( 'unicode' => '&#xf4f3;', 'styles' => array( 'sow-fab' ), ),
		'credit-card' => array( 'unicode' => '&#xf09d;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'critical-role' => array( 'unicode' => '&#xf6c9;', 'styles' => array( 'sow-fab' ), ),
		'crop' => array( 'unicode' => '&#xf125;', 'styles' => array( 'sow-fas' ), ),
		'crop-alt' => array( 'unicode' => '&#xf565;', 'styles' => array( 'sow-fas' ), ),
		'cross' => array( 'unicode' => '&#xf654;', 'styles' => array( 'sow-fas' ), ),
		'crosshairs' => array( 'unicode' => '&#xf05b;', 'styles' => array( 'sow-fas' ), ),
		'crow' => array( 'unicode' => '&#xf520;', 'styles' => array( 'sow-fas' ), ),
		'crown' => array( 'unicode' => '&#xf521;', 'styles' => array( 'sow-fas' ), ),
		'crutch' => array( 'unicode' => '&#xf7f7;', 'styles' => array( 'sow-fas' ), ),
		'css3' => array( 'unicode' => '&#xf13c;', 'styles' => array( 'sow-fab' ), ),
		'css3-alt' => array( 'unicode' => '&#xf38b;', 'styles' => array( 'sow-fab' ), ),
		'cube' => array( 'unicode' => '&#xf1b2;', 'styles' => array( 'sow-fas' ), ),
		'cubes' => array( 'unicode' => '&#xf1b3;', 'styles' => array( 'sow-fas' ), ),
		'cut' => array( 'unicode' => '&#xf0c4;', 'styles' => array( 'sow-fas' ), ),
		'cuttlefish' => array( 'unicode' => '&#xf38c;', 'styles' => array( 'sow-fab' ), ),
		'd-and-d' => array( 'unicode' => '&#xf38d;', 'styles' => array( 'sow-fab' ), ),
		'd-and-d-beyond' => array( 'unicode' => '&#xf6ca;', 'styles' => array( 'sow-fab' ), ),
		'dailymotion' => array( 'unicode' => '&#xe052;', 'styles' => array( 'sow-fab' ), ),
		'dashcube' => array( 'unicode' => '&#xf210;', 'styles' => array( 'sow-fab' ), ),
		'database' => array( 'unicode' => '&#xf1c0;', 'styles' => array( 'sow-fas' ), ),
		'deaf' => array( 'unicode' => '&#xf2a4;', 'styles' => array( 'sow-fas' ), ),
		'deezer' => array( 'unicode' => '&#xe077;', 'styles' => array( 'sow-fab' ), ),
		'delicious' => array( 'unicode' => '&#xf1a5;', 'styles' => array( 'sow-fab' ), ),
		'democrat' => array( 'unicode' => '&#xf747;', 'styles' => array( 'sow-fas' ), ),
		'deploydog' => array( 'unicode' => '&#xf38e;', 'styles' => array( 'sow-fab' ), ),
		'deskpro' => array( 'unicode' => '&#xf38f;', 'styles' => array( 'sow-fab' ), ),
		'desktop' => array( 'unicode' => '&#xf108;', 'styles' => array( 'sow-fas' ), ),
		'dev' => array( 'unicode' => '&#xf6cc;', 'styles' => array( 'sow-fab' ), ),
		'deviantart' => array( 'unicode' => '&#xf1bd;', 'styles' => array( 'sow-fab' ), ),
		'dharmachakra' => array( 'unicode' => '&#xf655;', 'styles' => array( 'sow-fas' ), ),
		'dhl' => array( 'unicode' => '&#xf790;', 'styles' => array( 'sow-fab' ), ),
		'diagnoses' => array( 'unicode' => '&#xf470;', 'styles' => array( 'sow-fas' ), ),
		'diaspora' => array( 'unicode' => '&#xf791;', 'styles' => array( 'sow-fab' ), ),
		'dice' => array( 'unicode' => '&#xf522;', 'styles' => array( 'sow-fas' ), ),
		'dice-d20' => array( 'unicode' => '&#xf6cf;', 'styles' => array( 'sow-fas' ), ),
		'dice-d6' => array( 'unicode' => '&#xf6d1;', 'styles' => array( 'sow-fas' ), ),
		'dice-five' => array( 'unicode' => '&#xf523;', 'styles' => array( 'sow-fas' ), ),
		'dice-four' => array( 'unicode' => '&#xf524;', 'styles' => array( 'sow-fas' ), ),
		'dice-one' => array( 'unicode' => '&#xf525;', 'styles' => array( 'sow-fas' ), ),
		'dice-six' => array( 'unicode' => '&#xf526;', 'styles' => array( 'sow-fas' ), ),
		'dice-three' => array( 'unicode' => '&#xf527;', 'styles' => array( 'sow-fas' ), ),
		'dice-two' => array( 'unicode' => '&#xf528;', 'styles' => array( 'sow-fas' ), ),
		'digg' => array( 'unicode' => '&#xf1a6;', 'styles' => array( 'sow-fab' ), ),
		'digital-ocean' => array( 'unicode' => '&#xf391;', 'styles' => array( 'sow-fab' ), ),
		'digital-tachograph' => array( 'unicode' => '&#xf566;', 'styles' => array( 'sow-fas' ), ),
		'directions' => array( 'unicode' => '&#xf5eb;', 'styles' => array( 'sow-fas' ), ),
		'discord' => array( 'unicode' => '&#xf392;', 'styles' => array( 'sow-fab' ), ),
		'discourse' => array( 'unicode' => '&#xf393;', 'styles' => array( 'sow-fab' ), ),
		'disease' => array( 'unicode' => '&#xf7fa;', 'styles' => array( 'sow-fas' ), ),
		'divide' => array( 'unicode' => '&#xf529;', 'styles' => array( 'sow-fas' ), ),
		'dizzy' => array( 'unicode' => '&#xf567;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'dna' => array( 'unicode' => '&#xf471;', 'styles' => array( 'sow-fas' ), ),
		'dochub' => array( 'unicode' => '&#xf394;', 'styles' => array( 'sow-fab' ), ),
		'docker' => array( 'unicode' => '&#xf395;', 'styles' => array( 'sow-fab' ), ),
		'dog' => array( 'unicode' => '&#xf6d3;', 'styles' => array( 'sow-fas' ), ),
		'dollar-sign' => array( 'unicode' => '&#xf155;', 'styles' => array( 'sow-fas' ), ),
		'dolly' => array( 'unicode' => '&#xf472;', 'styles' => array( 'sow-fas' ), ),
		'dolly-flatbed' => array( 'unicode' => '&#xf474;', 'styles' => array( 'sow-fas' ), ),
		'donate' => array( 'unicode' => '&#xf4b9;', 'styles' => array( 'sow-fas' ), ),
		'door-closed' => array( 'unicode' => '&#xf52a;', 'styles' => array( 'sow-fas' ), ),
		'door-open' => array( 'unicode' => '&#xf52b;', 'styles' => array( 'sow-fas' ), ),
		'dot-circle' => array( 'unicode' => '&#xf192;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'dove' => array( 'unicode' => '&#xf4ba;', 'styles' => array( 'sow-fas' ), ),
		'download' => array( 'unicode' => '&#xf019;', 'styles' => array( 'sow-fas' ), ),
		'draft2digital' => array( 'unicode' => '&#xf396;', 'styles' => array( 'sow-fab' ), ),
		'drafting-compass' => array( 'unicode' => '&#xf568;', 'styles' => array( 'sow-fas' ), ),
		'dragon' => array( 'unicode' => '&#xf6d5;', 'styles' => array( 'sow-fas' ), ),
		'draw-polygon' => array( 'unicode' => '&#xf5ee;', 'styles' => array( 'sow-fas' ), ),
		'dribbble' => array( 'unicode' => '&#xf17d;', 'styles' => array( 'sow-fab' ), ),
		'dribbble-square' => array( 'unicode' => '&#xf397;', 'styles' => array( 'sow-fab' ), ),
		'dropbox' => array( 'unicode' => '&#xf16b;', 'styles' => array( 'sow-fab' ), ),
		'drum' => array( 'unicode' => '&#xf569;', 'styles' => array( 'sow-fas' ), ),
		'drum-steelpan' => array( 'unicode' => '&#xf56a;', 'styles' => array( 'sow-fas' ), ),
		'drumstick-bite' => array( 'unicode' => '&#xf6d7;', 'styles' => array( 'sow-fas' ), ),
		'drupal' => array( 'unicode' => '&#xf1a9;', 'styles' => array( 'sow-fab' ), ),
		'dumbbell' => array( 'unicode' => '&#xf44b;', 'styles' => array( 'sow-fas' ), ),
		'dumpster' => array( 'unicode' => '&#xf793;', 'styles' => array( 'sow-fas' ), ),
		'dumpster-fire' => array( 'unicode' => '&#xf794;', 'styles' => array( 'sow-fas' ), ),
		'dungeon' => array( 'unicode' => '&#xf6d9;', 'styles' => array( 'sow-fas' ), ),
		'dyalog' => array( 'unicode' => '&#xf399;', 'styles' => array( 'sow-fab' ), ),
		'earlybirds' => array( 'unicode' => '&#xf39a;', 'styles' => array( 'sow-fab' ), ),
		'ebay' => array( 'unicode' => '&#xf4f4;', 'styles' => array( 'sow-fab' ), ),
		'edge' => array( 'unicode' => '&#xf282;', 'styles' => array( 'sow-fab' ), ),
		'edge-legacy' => array( 'unicode' => '&#xe078;', 'styles' => array( 'sow-fab' ), ),
		'edit' => array( 'unicode' => '&#xf044;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'egg' => array( 'unicode' => '&#xf7fb;', 'styles' => array( 'sow-fas' ), ),
		'eject' => array( 'unicode' => '&#xf052;', 'styles' => array( 'sow-fas' ), ),
		'elementor' => array( 'unicode' => '&#xf430;', 'styles' => array( 'sow-fab' ), ),
		'ellipsis-h' => array( 'unicode' => '&#xf141;', 'styles' => array( 'sow-fas' ), ),
		'ellipsis-v' => array( 'unicode' => '&#xf142;', 'styles' => array( 'sow-fas' ), ),
		'ello' => array( 'unicode' => '&#xf5f1;', 'styles' => array( 'sow-fab' ), ),
		'ember' => array( 'unicode' => '&#xf423;', 'styles' => array( 'sow-fab' ), ),
		'empire' => array( 'unicode' => '&#xf1d1;', 'styles' => array( 'sow-fab' ), ),
		'envelope' => array( 'unicode' => '&#xf0e0;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'envelope-open' => array( 'unicode' => '&#xf2b6;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'envelope-open-text' => array( 'unicode' => '&#xf658;', 'styles' => array( 'sow-fas' ), ),
		'envelope-square' => array( 'unicode' => '&#xf199;', 'styles' => array( 'sow-fas' ), ),
		'envira' => array( 'unicode' => '&#xf299;', 'styles' => array( 'sow-fab' ), ),
		'equals' => array( 'unicode' => '&#xf52c;', 'styles' => array( 'sow-fas' ), ),
		'eraser' => array( 'unicode' => '&#xf12d;', 'styles' => array( 'sow-fas' ), ),
		'erlang' => array( 'unicode' => '&#xf39d;', 'styles' => array( 'sow-fab' ), ),
		'ethereum' => array( 'unicode' => '&#xf42e;', 'styles' => array( 'sow-fab' ), ),
		'ethernet' => array( 'unicode' => '&#xf796;', 'styles' => array( 'sow-fas' ), ),
		'etsy' => array( 'unicode' => '&#xf2d7;', 'styles' => array( 'sow-fab' ), ),
		'euro-sign' => array( 'unicode' => '&#xf153;', 'styles' => array( 'sow-fas' ), ),
		'evernote' => array( 'unicode' => '&#xf839;', 'styles' => array( 'sow-fab' ), ),
		'exchange-alt' => array( 'unicode' => '&#xf362;', 'styles' => array( 'sow-fas' ), ),
		'exclamation' => array( 'unicode' => '&#xf12a;', 'styles' => array( 'sow-fas' ), ),
		'exclamation-circle' => array( 'unicode' => '&#xf06a;', 'styles' => array( 'sow-fas' ), ),
		'exclamation-triangle' => array( 'unicode' => '&#xf071;', 'styles' => array( 'sow-fas' ), ),
		'expand' => array( 'unicode' => '&#xf065;', 'styles' => array( 'sow-fas' ), ),
		'expand-alt' => array( 'unicode' => '&#xf424;', 'styles' => array( 'sow-fas' ), ),
		'expand-arrows-alt' => array( 'unicode' => '&#xf31e;', 'styles' => array( 'sow-fas' ), ),
		'expeditedssl' => array( 'unicode' => '&#xf23e;', 'styles' => array( 'sow-fab' ), ),
		'external-link-alt' => array( 'unicode' => '&#xf35d;', 'styles' => array( 'sow-fas' ), ),
		'external-link-square-alt' => array( 'unicode' => '&#xf360;', 'styles' => array( 'sow-fas' ), ),
		'eye' => array( 'unicode' => '&#xf06e;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'eye-dropper' => array( 'unicode' => '&#xf1fb;', 'styles' => array( 'sow-fas' ), ),
		'eye-slash' => array( 'unicode' => '&#xf070;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'facebook' => array( 'unicode' => '&#xf09a;', 'styles' => array( 'sow-fab' ), ),
		'facebook-f' => array( 'unicode' => '&#xf39e;', 'styles' => array( 'sow-fab' ), ),
		'facebook-messenger' => array( 'unicode' => '&#xf39f;', 'styles' => array( 'sow-fab' ), ),
		'facebook-square' => array( 'unicode' => '&#xf082;', 'styles' => array( 'sow-fab' ), ),
		'fan' => array( 'unicode' => '&#xf863;', 'styles' => array( 'sow-fas' ), ),
		'fantasy-flight-games' => array( 'unicode' => '&#xf6dc;', 'styles' => array( 'sow-fab' ), ),
		'fast-backward' => array( 'unicode' => '&#xf049;', 'styles' => array( 'sow-fas' ), ),
		'fast-forward' => array( 'unicode' => '&#xf050;', 'styles' => array( 'sow-fas' ), ),
		'faucet' => array( 'unicode' => '&#xe005;', 'styles' => array( 'sow-fas' ), ),
		'fax' => array( 'unicode' => '&#xf1ac;', 'styles' => array( 'sow-fas' ), ),
		'feather' => array( 'unicode' => '&#xf52d;', 'styles' => array( 'sow-fas' ), ),
		'feather-alt' => array( 'unicode' => '&#xf56b;', 'styles' => array( 'sow-fas' ), ),
		'fedex' => array( 'unicode' => '&#xf797;', 'styles' => array( 'sow-fab' ), ),
		'fedora' => array( 'unicode' => '&#xf798;', 'styles' => array( 'sow-fab' ), ),
		'female' => array( 'unicode' => '&#xf182;', 'styles' => array( 'sow-fas' ), ),
		'fighter-jet' => array( 'unicode' => '&#xf0fb;', 'styles' => array( 'sow-fas' ), ),
		'figma' => array( 'unicode' => '&#xf799;', 'styles' => array( 'sow-fab' ), ),
		'file' => array( 'unicode' => '&#xf15b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-alt' => array( 'unicode' => '&#xf15c;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-archive' => array( 'unicode' => '&#xf1c6;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-audio' => array( 'unicode' => '&#xf1c7;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-code' => array( 'unicode' => '&#xf1c9;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-contract' => array( 'unicode' => '&#xf56c;', 'styles' => array( 'sow-fas' ), ),
		'file-csv' => array( 'unicode' => '&#xf6dd;', 'styles' => array( 'sow-fas' ), ),
		'file-download' => array( 'unicode' => '&#xf56d;', 'styles' => array( 'sow-fas' ), ),
		'file-excel' => array( 'unicode' => '&#xf1c3;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-export' => array( 'unicode' => '&#xf56e;', 'styles' => array( 'sow-fas' ), ),
		'file-image' => array( 'unicode' => '&#xf1c5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-import' => array( 'unicode' => '&#xf56f;', 'styles' => array( 'sow-fas' ), ),
		'file-invoice' => array( 'unicode' => '&#xf570;', 'styles' => array( 'sow-fas' ), ),
		'file-invoice-dollar' => array( 'unicode' => '&#xf571;', 'styles' => array( 'sow-fas' ), ),
		'file-medical' => array( 'unicode' => '&#xf477;', 'styles' => array( 'sow-fas' ), ),
		'file-medical-alt' => array( 'unicode' => '&#xf478;', 'styles' => array( 'sow-fas' ), ),
		'file-pdf' => array( 'unicode' => '&#xf1c1;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-powerpoint' => array( 'unicode' => '&#xf1c4;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-prescription' => array( 'unicode' => '&#xf572;', 'styles' => array( 'sow-fas' ), ),
		'file-signature' => array( 'unicode' => '&#xf573;', 'styles' => array( 'sow-fas' ), ),
		'file-upload' => array( 'unicode' => '&#xf574;', 'styles' => array( 'sow-fas' ), ),
		'file-video' => array( 'unicode' => '&#xf1c8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'file-word' => array( 'unicode' => '&#xf1c2;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'fill' => array( 'unicode' => '&#xf575;', 'styles' => array( 'sow-fas' ), ),
		'fill-drip' => array( 'unicode' => '&#xf576;', 'styles' => array( 'sow-fas' ), ),
		'film' => array( 'unicode' => '&#xf008;', 'styles' => array( 'sow-fas' ), ),
		'filter' => array( 'unicode' => '&#xf0b0;', 'styles' => array( 'sow-fas' ), ),
		'fingerprint' => array( 'unicode' => '&#xf577;', 'styles' => array( 'sow-fas' ), ),
		'fire' => array( 'unicode' => '&#xf06d;', 'styles' => array( 'sow-fas' ), ),
		'fire-alt' => array( 'unicode' => '&#xf7e4;', 'styles' => array( 'sow-fas' ), ),
		'fire-extinguisher' => array( 'unicode' => '&#xf134;', 'styles' => array( 'sow-fas' ), ),
		'firefox' => array( 'unicode' => '&#xf269;', 'styles' => array( 'sow-fab' ), ),
		'firefox-browser' => array( 'unicode' => '&#xe007;', 'styles' => array( 'sow-fab' ), ),
		'first-aid' => array( 'unicode' => '&#xf479;', 'styles' => array( 'sow-fas' ), ),
		'first-order' => array( 'unicode' => '&#xf2b0;', 'styles' => array( 'sow-fab' ), ),
		'first-order-alt' => array( 'unicode' => '&#xf50a;', 'styles' => array( 'sow-fab' ), ),
		'firstdraft' => array( 'unicode' => '&#xf3a1;', 'styles' => array( 'sow-fab' ), ),
		'fish' => array( 'unicode' => '&#xf578;', 'styles' => array( 'sow-fas' ), ),
		'fist-raised' => array( 'unicode' => '&#xf6de;', 'styles' => array( 'sow-fas' ), ),
		'flag' => array( 'unicode' => '&#xf024;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'flag-checkered' => array( 'unicode' => '&#xf11e;', 'styles' => array( 'sow-fas' ), ),
		'flag-usa' => array( 'unicode' => '&#xf74d;', 'styles' => array( 'sow-fas' ), ),
		'flask' => array( 'unicode' => '&#xf0c3;', 'styles' => array( 'sow-fas' ), ),
		'flickr' => array( 'unicode' => '&#xf16e;', 'styles' => array( 'sow-fab' ), ),
		'flipboard' => array( 'unicode' => '&#xf44d;', 'styles' => array( 'sow-fab' ), ),
		'flushed' => array( 'unicode' => '&#xf579;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'fly' => array( 'unicode' => '&#xf417;', 'styles' => array( 'sow-fab' ), ),
		'folder' => array( 'unicode' => '&#xf07b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'folder-minus' => array( 'unicode' => '&#xf65d;', 'styles' => array( 'sow-fas' ), ),
		'folder-open' => array( 'unicode' => '&#xf07c;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'folder-plus' => array( 'unicode' => '&#xf65e;', 'styles' => array( 'sow-fas' ), ),
		'font' => array( 'unicode' => '&#xf031;', 'styles' => array( 'sow-fas' ), ),
		'font-awesome' => array( 'unicode' => '&#xf2b4;', 'styles' => array( 'sow-fab' ), ),
		'font-awesome-alt' => array( 'unicode' => '&#xf35c;', 'styles' => array( 'sow-fab' ), ),
		'font-awesome-flag' => array( 'unicode' => '&#xf425;', 'styles' => array( 'sow-fab' ), ),
		'font-awesome-logo-full' => array( 'unicode' => '&#xf4e6;', 'styles' => array( 'sow-far', 'sow-fas', 'sow-fab' ), ),
		'fonticons' => array( 'unicode' => '&#xf280;', 'styles' => array( 'sow-fab' ), ),
		'fonticons-fi' => array( 'unicode' => '&#xf3a2;', 'styles' => array( 'sow-fab' ), ),
		'football-ball' => array( 'unicode' => '&#xf44e;', 'styles' => array( 'sow-fas' ), ),
		'fort-awesome' => array( 'unicode' => '&#xf286;', 'styles' => array( 'sow-fab' ), ),
		'fort-awesome-alt' => array( 'unicode' => '&#xf3a3;', 'styles' => array( 'sow-fab' ), ),
		'forumbee' => array( 'unicode' => '&#xf211;', 'styles' => array( 'sow-fab' ), ),
		'forward' => array( 'unicode' => '&#xf04e;', 'styles' => array( 'sow-fas' ), ),
		'foursquare' => array( 'unicode' => '&#xf180;', 'styles' => array( 'sow-fab' ), ),
		'free-code-camp' => array( 'unicode' => '&#xf2c5;', 'styles' => array( 'sow-fab' ), ),
		'freebsd' => array( 'unicode' => '&#xf3a4;', 'styles' => array( 'sow-fab' ), ),
		'frog' => array( 'unicode' => '&#xf52e;', 'styles' => array( 'sow-fas' ), ),
		'frown' => array( 'unicode' => '&#xf119;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'frown-open' => array( 'unicode' => '&#xf57a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'fulcrum' => array( 'unicode' => '&#xf50b;', 'styles' => array( 'sow-fab' ), ),
		'funnel-dollar' => array( 'unicode' => '&#xf662;', 'styles' => array( 'sow-fas' ), ),
		'futbol' => array( 'unicode' => '&#xf1e3;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'galactic-republic' => array( 'unicode' => '&#xf50c;', 'styles' => array( 'sow-fab' ), ),
		'galactic-senate' => array( 'unicode' => '&#xf50d;', 'styles' => array( 'sow-fab' ), ),
		'gamepad' => array( 'unicode' => '&#xf11b;', 'styles' => array( 'sow-fas' ), ),
		'gas-pump' => array( 'unicode' => '&#xf52f;', 'styles' => array( 'sow-fas' ), ),
		'gavel' => array( 'unicode' => '&#xf0e3;', 'styles' => array( 'sow-fas' ), ),
		'gem' => array( 'unicode' => '&#xf3a5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'genderless' => array( 'unicode' => '&#xf22d;', 'styles' => array( 'sow-fas' ), ),
		'get-pocket' => array( 'unicode' => '&#xf265;', 'styles' => array( 'sow-fab' ), ),
		'gg' => array( 'unicode' => '&#xf260;', 'styles' => array( 'sow-fab' ), ),
		'gg-circle' => array( 'unicode' => '&#xf261;', 'styles' => array( 'sow-fab' ), ),
		'ghost' => array( 'unicode' => '&#xf6e2;', 'styles' => array( 'sow-fas' ), ),
		'gift' => array( 'unicode' => '&#xf06b;', 'styles' => array( 'sow-fas' ), ),
		'gifts' => array( 'unicode' => '&#xf79c;', 'styles' => array( 'sow-fas' ), ),
		'git' => array( 'unicode' => '&#xf1d3;', 'styles' => array( 'sow-fab' ), ),
		'git-alt' => array( 'unicode' => '&#xf841;', 'styles' => array( 'sow-fab' ), ),
		'git-square' => array( 'unicode' => '&#xf1d2;', 'styles' => array( 'sow-fab' ), ),
		'github' => array( 'unicode' => '&#xf09b;', 'styles' => array( 'sow-fab' ), ),
		'github-alt' => array( 'unicode' => '&#xf113;', 'styles' => array( 'sow-fab' ), ),
		'github-square' => array( 'unicode' => '&#xf092;', 'styles' => array( 'sow-fab' ), ),
		'gitkraken' => array( 'unicode' => '&#xf3a6;', 'styles' => array( 'sow-fab' ), ),
		'gitlab' => array( 'unicode' => '&#xf296;', 'styles' => array( 'sow-fab' ), ),
		'gitter' => array( 'unicode' => '&#xf426;', 'styles' => array( 'sow-fab' ), ),
		'glass-cheers' => array( 'unicode' => '&#xf79f;', 'styles' => array( 'sow-fas' ), ),
		'glass-martini' => array( 'unicode' => '&#xf000;', 'styles' => array( 'sow-fas' ), ),
		'glass-martini-alt' => array( 'unicode' => '&#xf57b;', 'styles' => array( 'sow-fas' ), ),
		'glass-whiskey' => array( 'unicode' => '&#xf7a0;', 'styles' => array( 'sow-fas' ), ),
		'glasses' => array( 'unicode' => '&#xf530;', 'styles' => array( 'sow-fas' ), ),
		'glide' => array( 'unicode' => '&#xf2a5;', 'styles' => array( 'sow-fab' ), ),
		'glide-g' => array( 'unicode' => '&#xf2a6;', 'styles' => array( 'sow-fab' ), ),
		'globe' => array( 'unicode' => '&#xf0ac;', 'styles' => array( 'sow-fas' ), ),
		'globe-africa' => array( 'unicode' => '&#xf57c;', 'styles' => array( 'sow-fas' ), ),
		'globe-americas' => array( 'unicode' => '&#xf57d;', 'styles' => array( 'sow-fas' ), ),
		'globe-asia' => array( 'unicode' => '&#xf57e;', 'styles' => array( 'sow-fas' ), ),
		'globe-europe' => array( 'unicode' => '&#xf7a2;', 'styles' => array( 'sow-fas' ), ),
		'gofore' => array( 'unicode' => '&#xf3a7;', 'styles' => array( 'sow-fab' ), ),
		'golf-ball' => array( 'unicode' => '&#xf450;', 'styles' => array( 'sow-fas' ), ),
		'goodreads' => array( 'unicode' => '&#xf3a8;', 'styles' => array( 'sow-fab' ), ),
		'goodreads-g' => array( 'unicode' => '&#xf3a9;', 'styles' => array( 'sow-fab' ), ),
		'google' => array( 'unicode' => '&#xf1a0;', 'styles' => array( 'sow-fab' ), ),
		'google-drive' => array( 'unicode' => '&#xf3aa;', 'styles' => array( 'sow-fab' ), ),
		'google-pay' => array( 'unicode' => '&#xe079;', 'styles' => array( 'sow-fab' ), ),
		'google-play' => array( 'unicode' => '&#xf3ab;', 'styles' => array( 'sow-fab' ), ),
		'google-plus' => array( 'unicode' => '&#xf2b3;', 'styles' => array( 'sow-fab' ), ),
		'google-plus-g' => array( 'unicode' => '&#xf0d5;', 'styles' => array( 'sow-fab' ), ),
		'google-plus-square' => array( 'unicode' => '&#xf0d4;', 'styles' => array( 'sow-fab' ), ),
		'google-wallet' => array( 'unicode' => '&#xf1ee;', 'styles' => array( 'sow-fab' ), ),
		'gopuram' => array( 'unicode' => '&#xf664;', 'styles' => array( 'sow-fas' ), ),
		'graduation-cap' => array( 'unicode' => '&#xf19d;', 'styles' => array( 'sow-fas' ), ),
		'gratipay' => array( 'unicode' => '&#xf184;', 'styles' => array( 'sow-fab' ), ),
		'grav' => array( 'unicode' => '&#xf2d6;', 'styles' => array( 'sow-fab' ), ),
		'greater-than' => array( 'unicode' => '&#xf531;', 'styles' => array( 'sow-fas' ), ),
		'greater-than-equal' => array( 'unicode' => '&#xf532;', 'styles' => array( 'sow-fas' ), ),
		'grimace' => array( 'unicode' => '&#xf57f;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin' => array( 'unicode' => '&#xf580;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-alt' => array( 'unicode' => '&#xf581;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-beam' => array( 'unicode' => '&#xf582;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-beam-sweat' => array( 'unicode' => '&#xf583;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-hearts' => array( 'unicode' => '&#xf584;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-squint' => array( 'unicode' => '&#xf585;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-squint-tears' => array( 'unicode' => '&#xf586;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-stars' => array( 'unicode' => '&#xf587;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-tears' => array( 'unicode' => '&#xf588;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-tongue' => array( 'unicode' => '&#xf589;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-tongue-squint' => array( 'unicode' => '&#xf58a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-tongue-wink' => array( 'unicode' => '&#xf58b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grin-wink' => array( 'unicode' => '&#xf58c;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'grip-horizontal' => array( 'unicode' => '&#xf58d;', 'styles' => array( 'sow-fas' ), ),
		'grip-lines' => array( 'unicode' => '&#xf7a4;', 'styles' => array( 'sow-fas' ), ),
		'grip-lines-vertical' => array( 'unicode' => '&#xf7a5;', 'styles' => array( 'sow-fas' ), ),
		'grip-vertical' => array( 'unicode' => '&#xf58e;', 'styles' => array( 'sow-fas' ), ),
		'gripfire' => array( 'unicode' => '&#xf3ac;', 'styles' => array( 'sow-fab' ), ),
		'grunt' => array( 'unicode' => '&#xf3ad;', 'styles' => array( 'sow-fab' ), ),
		'guilded' => array( 'unicode' => '&#xe07e;', 'styles' => array( 'sow-fab' ), ),
		'guitar' => array( 'unicode' => '&#xf7a6;', 'styles' => array( 'sow-fas' ), ),
		'gulp' => array( 'unicode' => '&#xf3ae;', 'styles' => array( 'sow-fab' ), ),
		'h-square' => array( 'unicode' => '&#xf0fd;', 'styles' => array( 'sow-fas' ), ),
		'hacker-news' => array( 'unicode' => '&#xf1d4;', 'styles' => array( 'sow-fab' ), ),
		'hacker-news-square' => array( 'unicode' => '&#xf3af;', 'styles' => array( 'sow-fab' ), ),
		'hackerrank' => array( 'unicode' => '&#xf5f7;', 'styles' => array( 'sow-fab' ), ),
		'hamburger' => array( 'unicode' => '&#xf805;', 'styles' => array( 'sow-fas' ), ),
		'hammer' => array( 'unicode' => '&#xf6e3;', 'styles' => array( 'sow-fas' ), ),
		'hamsa' => array( 'unicode' => '&#xf665;', 'styles' => array( 'sow-fas' ), ),
		'hand-holding' => array( 'unicode' => '&#xf4bd;', 'styles' => array( 'sow-fas' ), ),
		'hand-holding-heart' => array( 'unicode' => '&#xf4be;', 'styles' => array( 'sow-fas' ), ),
		'hand-holding-medical' => array( 'unicode' => '&#xe05c;', 'styles' => array( 'sow-fas' ), ),
		'hand-holding-usd' => array( 'unicode' => '&#xf4c0;', 'styles' => array( 'sow-fas' ), ),
		'hand-holding-water' => array( 'unicode' => '&#xf4c1;', 'styles' => array( 'sow-fas' ), ),
		'hand-lizard' => array( 'unicode' => '&#xf258;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-middle-finger' => array( 'unicode' => '&#xf806;', 'styles' => array( 'sow-fas' ), ),
		'hand-paper' => array( 'unicode' => '&#xf256;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-peace' => array( 'unicode' => '&#xf25b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-point-down' => array( 'unicode' => '&#xf0a7;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-point-left' => array( 'unicode' => '&#xf0a5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-point-right' => array( 'unicode' => '&#xf0a4;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-point-up' => array( 'unicode' => '&#xf0a6;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-pointer' => array( 'unicode' => '&#xf25a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-rock' => array( 'unicode' => '&#xf255;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-scissors' => array( 'unicode' => '&#xf257;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hand-sparkles' => array( 'unicode' => '&#xe05d;', 'styles' => array( 'sow-fas' ), ),
		'hand-spock' => array( 'unicode' => '&#xf259;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hands' => array( 'unicode' => '&#xf4c2;', 'styles' => array( 'sow-fas' ), ),
		'hands-helping' => array( 'unicode' => '&#xf4c4;', 'styles' => array( 'sow-fas' ), ),
		'hands-wash' => array( 'unicode' => '&#xe05e;', 'styles' => array( 'sow-fas' ), ),
		'handshake' => array( 'unicode' => '&#xf2b5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'handshake-alt-slash' => array( 'unicode' => '&#xe05f;', 'styles' => array( 'sow-fas' ), ),
		'handshake-slash' => array( 'unicode' => '&#xe060;', 'styles' => array( 'sow-fas' ), ),
		'hanukiah' => array( 'unicode' => '&#xf6e6;', 'styles' => array( 'sow-fas' ), ),
		'hard-hat' => array( 'unicode' => '&#xf807;', 'styles' => array( 'sow-fas' ), ),
		'hashtag' => array( 'unicode' => '&#xf292;', 'styles' => array( 'sow-fas' ), ),
		'hat-cowboy' => array( 'unicode' => '&#xf8c0;', 'styles' => array( 'sow-fas' ), ),
		'hat-cowboy-side' => array( 'unicode' => '&#xf8c1;', 'styles' => array( 'sow-fas' ), ),
		'hat-wizard' => array( 'unicode' => '&#xf6e8;', 'styles' => array( 'sow-fas' ), ),
		'hdd' => array( 'unicode' => '&#xf0a0;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'head-side-cough' => array( 'unicode' => '&#xe061;', 'styles' => array( 'sow-fas' ), ),
		'head-side-cough-slash' => array( 'unicode' => '&#xe062;', 'styles' => array( 'sow-fas' ), ),
		'head-side-mask' => array( 'unicode' => '&#xe063;', 'styles' => array( 'sow-fas' ), ),
		'head-side-virus' => array( 'unicode' => '&#xe064;', 'styles' => array( 'sow-fas' ), ),
		'heading' => array( 'unicode' => '&#xf1dc;', 'styles' => array( 'sow-fas' ), ),
		'headphones' => array( 'unicode' => '&#xf025;', 'styles' => array( 'sow-fas' ), ),
		'headphones-alt' => array( 'unicode' => '&#xf58f;', 'styles' => array( 'sow-fas' ), ),
		'headset' => array( 'unicode' => '&#xf590;', 'styles' => array( 'sow-fas' ), ),
		'heart' => array( 'unicode' => '&#xf004;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'heart-broken' => array( 'unicode' => '&#xf7a9;', 'styles' => array( 'sow-fas' ), ),
		'heartbeat' => array( 'unicode' => '&#xf21e;', 'styles' => array( 'sow-fas' ), ),
		'helicopter' => array( 'unicode' => '&#xf533;', 'styles' => array( 'sow-fas' ), ),
		'highlighter' => array( 'unicode' => '&#xf591;', 'styles' => array( 'sow-fas' ), ),
		'hiking' => array( 'unicode' => '&#xf6ec;', 'styles' => array( 'sow-fas' ), ),
		'hippo' => array( 'unicode' => '&#xf6ed;', 'styles' => array( 'sow-fas' ), ),
		'hips' => array( 'unicode' => '&#xf452;', 'styles' => array( 'sow-fab' ), ),
		'hire-a-helper' => array( 'unicode' => '&#xf3b0;', 'styles' => array( 'sow-fab' ), ),
		'history' => array( 'unicode' => '&#xf1da;', 'styles' => array( 'sow-fas' ), ),
		'hive' => array( 'unicode' => '&#xe07f;', 'styles' => array( 'sow-fab' ), ),
		'hockey-puck' => array( 'unicode' => '&#xf453;', 'styles' => array( 'sow-fas' ), ),
		'holly-berry' => array( 'unicode' => '&#xf7aa;', 'styles' => array( 'sow-fas' ), ),
		'home' => array( 'unicode' => '&#xf015;', 'styles' => array( 'sow-fas' ), ),
		'hooli' => array( 'unicode' => '&#xf427;', 'styles' => array( 'sow-fab' ), ),
		'hornbill' => array( 'unicode' => '&#xf592;', 'styles' => array( 'sow-fab' ), ),
		'horse' => array( 'unicode' => '&#xf6f0;', 'styles' => array( 'sow-fas' ), ),
		'horse-head' => array( 'unicode' => '&#xf7ab;', 'styles' => array( 'sow-fas' ), ),
		'hospital' => array( 'unicode' => '&#xf0f8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hospital-alt' => array( 'unicode' => '&#xf47d;', 'styles' => array( 'sow-fas' ), ),
		'hospital-symbol' => array( 'unicode' => '&#xf47e;', 'styles' => array( 'sow-fas' ), ),
		'hospital-user' => array( 'unicode' => '&#xf80d;', 'styles' => array( 'sow-fas' ), ),
		'hot-tub' => array( 'unicode' => '&#xf593;', 'styles' => array( 'sow-fas' ), ),
		'hotdog' => array( 'unicode' => '&#xf80f;', 'styles' => array( 'sow-fas' ), ),
		'hotel' => array( 'unicode' => '&#xf594;', 'styles' => array( 'sow-fas' ), ),
		'hotjar' => array( 'unicode' => '&#xf3b1;', 'styles' => array( 'sow-fab' ), ),
		'hourglass' => array( 'unicode' => '&#xf254;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'hourglass-end' => array( 'unicode' => '&#xf253;', 'styles' => array( 'sow-fas' ), ),
		'hourglass-half' => array( 'unicode' => '&#xf252;', 'styles' => array( 'sow-fas' ), ),
		'hourglass-start' => array( 'unicode' => '&#xf251;', 'styles' => array( 'sow-fas' ), ),
		'house-damage' => array( 'unicode' => '&#xf6f1;', 'styles' => array( 'sow-fas' ), ),
		'house-user' => array( 'unicode' => '&#xe065;', 'styles' => array( 'sow-fas' ), ),
		'houzz' => array( 'unicode' => '&#xf27c;', 'styles' => array( 'sow-fab' ), ),
		'hryvnia' => array( 'unicode' => '&#xf6f2;', 'styles' => array( 'sow-fas' ), ),
		'html5' => array( 'unicode' => '&#xf13b;', 'styles' => array( 'sow-fab' ), ),
		'hubspot' => array( 'unicode' => '&#xf3b2;', 'styles' => array( 'sow-fab' ), ),
		'i-cursor' => array( 'unicode' => '&#xf246;', 'styles' => array( 'sow-fas' ), ),
		'ice-cream' => array( 'unicode' => '&#xf810;', 'styles' => array( 'sow-fas' ), ),
		'icicles' => array( 'unicode' => '&#xf7ad;', 'styles' => array( 'sow-fas' ), ),
		'icons' => array( 'unicode' => '&#xf86d;', 'styles' => array( 'sow-fas' ), ),
		'id-badge' => array( 'unicode' => '&#xf2c1;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'id-card' => array( 'unicode' => '&#xf2c2;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'id-card-alt' => array( 'unicode' => '&#xf47f;', 'styles' => array( 'sow-fas' ), ),
		'ideal' => array( 'unicode' => '&#xe013;', 'styles' => array( 'sow-fab' ), ),
		'igloo' => array( 'unicode' => '&#xf7ae;', 'styles' => array( 'sow-fas' ), ),
		'image' => array( 'unicode' => '&#xf03e;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'images' => array( 'unicode' => '&#xf302;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'imdb' => array( 'unicode' => '&#xf2d8;', 'styles' => array( 'sow-fab' ), ),
		'inbox' => array( 'unicode' => '&#xf01c;', 'styles' => array( 'sow-fas' ), ),
		'indent' => array( 'unicode' => '&#xf03c;', 'styles' => array( 'sow-fas' ), ),
		'industry' => array( 'unicode' => '&#xf275;', 'styles' => array( 'sow-fas' ), ),
		'infinity' => array( 'unicode' => '&#xf534;', 'styles' => array( 'sow-fas' ), ),
		'info' => array( 'unicode' => '&#xf129;', 'styles' => array( 'sow-fas' ), ),
		'info-circle' => array( 'unicode' => '&#xf05a;', 'styles' => array( 'sow-fas' ), ),
		'innosoft' => array( 'unicode' => '&#xe080;', 'styles' => array( 'sow-fab' ), ),
		'instagram' => array( 'unicode' => '&#xf16d;', 'styles' => array( 'sow-fab' ), ),
		'instagram-square' => array( 'unicode' => '&#xe055;', 'styles' => array( 'sow-fab' ), ),
		'instalod' => array( 'unicode' => '&#xe081;', 'styles' => array( 'sow-fab' ), ),
		'intercom' => array( 'unicode' => '&#xf7af;', 'styles' => array( 'sow-fab' ), ),
		'internet-explorer' => array( 'unicode' => '&#xf26b;', 'styles' => array( 'sow-fab' ), ),
		'invision' => array( 'unicode' => '&#xf7b0;', 'styles' => array( 'sow-fab' ), ),
		'ioxhost' => array( 'unicode' => '&#xf208;', 'styles' => array( 'sow-fab' ), ),
		'italic' => array( 'unicode' => '&#xf033;', 'styles' => array( 'sow-fas' ), ),
		'itch-io' => array( 'unicode' => '&#xf83a;', 'styles' => array( 'sow-fab' ), ),
		'itunes' => array( 'unicode' => '&#xf3b4;', 'styles' => array( 'sow-fab' ), ),
		'itunes-note' => array( 'unicode' => '&#xf3b5;', 'styles' => array( 'sow-fab' ), ),
		'java' => array( 'unicode' => '&#xf4e4;', 'styles' => array( 'sow-fab' ), ),
		'jedi' => array( 'unicode' => '&#xf669;', 'styles' => array( 'sow-fas' ), ),
		'jedi-order' => array( 'unicode' => '&#xf50e;', 'styles' => array( 'sow-fab' ), ),
		'jenkins' => array( 'unicode' => '&#xf3b6;', 'styles' => array( 'sow-fab' ), ),
		'jira' => array( 'unicode' => '&#xf7b1;', 'styles' => array( 'sow-fab' ), ),
		'joget' => array( 'unicode' => '&#xf3b7;', 'styles' => array( 'sow-fab' ), ),
		'joint' => array( 'unicode' => '&#xf595;', 'styles' => array( 'sow-fas' ), ),
		'joomla' => array( 'unicode' => '&#xf1aa;', 'styles' => array( 'sow-fab' ), ),
		'journal-whills' => array( 'unicode' => '&#xf66a;', 'styles' => array( 'sow-fas' ), ),
		'js' => array( 'unicode' => '&#xf3b8;', 'styles' => array( 'sow-fab' ), ),
		'js-square' => array( 'unicode' => '&#xf3b9;', 'styles' => array( 'sow-fab' ), ),
		'jsfiddle' => array( 'unicode' => '&#xf1cc;', 'styles' => array( 'sow-fab' ), ),
		'kaaba' => array( 'unicode' => '&#xf66b;', 'styles' => array( 'sow-fas' ), ),
		'kaggle' => array( 'unicode' => '&#xf5fa;', 'styles' => array( 'sow-fab' ), ),
		'key' => array( 'unicode' => '&#xf084;', 'styles' => array( 'sow-fas' ), ),
		'keybase' => array( 'unicode' => '&#xf4f5;', 'styles' => array( 'sow-fab' ), ),
		'keyboard' => array( 'unicode' => '&#xf11c;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'keycdn' => array( 'unicode' => '&#xf3ba;', 'styles' => array( 'sow-fab' ), ),
		'khanda' => array( 'unicode' => '&#xf66d;', 'styles' => array( 'sow-fas' ), ),
		'kickstarter' => array( 'unicode' => '&#xf3bb;', 'styles' => array( 'sow-fab' ), ),
		'kickstarter-k' => array( 'unicode' => '&#xf3bc;', 'styles' => array( 'sow-fab' ), ),
		'kiss' => array( 'unicode' => '&#xf596;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'kiss-beam' => array( 'unicode' => '&#xf597;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'kiss-wink-heart' => array( 'unicode' => '&#xf598;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'kiwi-bird' => array( 'unicode' => '&#xf535;', 'styles' => array( 'sow-fas' ), ),
		'korvue' => array( 'unicode' => '&#xf42f;', 'styles' => array( 'sow-fab' ), ),
		'landmark' => array( 'unicode' => '&#xf66f;', 'styles' => array( 'sow-fas' ), ),
		'language' => array( 'unicode' => '&#xf1ab;', 'styles' => array( 'sow-fas' ), ),
		'laptop' => array( 'unicode' => '&#xf109;', 'styles' => array( 'sow-fas' ), ),
		'laptop-code' => array( 'unicode' => '&#xf5fc;', 'styles' => array( 'sow-fas' ), ),
		'laptop-house' => array( 'unicode' => '&#xe066;', 'styles' => array( 'sow-fas' ), ),
		'laptop-medical' => array( 'unicode' => '&#xf812;', 'styles' => array( 'sow-fas' ), ),
		'laravel' => array( 'unicode' => '&#xf3bd;', 'styles' => array( 'sow-fab' ), ),
		'lastfm' => array( 'unicode' => '&#xf202;', 'styles' => array( 'sow-fab' ), ),
		'lastfm-square' => array( 'unicode' => '&#xf203;', 'styles' => array( 'sow-fab' ), ),
		'laugh' => array( 'unicode' => '&#xf599;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'laugh-beam' => array( 'unicode' => '&#xf59a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'laugh-squint' => array( 'unicode' => '&#xf59b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'laugh-wink' => array( 'unicode' => '&#xf59c;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'layer-group' => array( 'unicode' => '&#xf5fd;', 'styles' => array( 'sow-fas' ), ),
		'leaf' => array( 'unicode' => '&#xf06c;', 'styles' => array( 'sow-fas' ), ),
		'leanpub' => array( 'unicode' => '&#xf212;', 'styles' => array( 'sow-fab' ), ),
		'lemon' => array( 'unicode' => '&#xf094;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'less' => array( 'unicode' => '&#xf41d;', 'styles' => array( 'sow-fab' ), ),
		'less-than' => array( 'unicode' => '&#xf536;', 'styles' => array( 'sow-fas' ), ),
		'less-than-equal' => array( 'unicode' => '&#xf537;', 'styles' => array( 'sow-fas' ), ),
		'level-down-alt' => array( 'unicode' => '&#xf3be;', 'styles' => array( 'sow-fas' ), ),
		'level-up-alt' => array( 'unicode' => '&#xf3bf;', 'styles' => array( 'sow-fas' ), ),
		'life-ring' => array( 'unicode' => '&#xf1cd;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'lightbulb' => array( 'unicode' => '&#xf0eb;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'line' => array( 'unicode' => '&#xf3c0;', 'styles' => array( 'sow-fab' ), ),
		'link' => array( 'unicode' => '&#xf0c1;', 'styles' => array( 'sow-fas' ), ),
		'linkedin' => array( 'unicode' => '&#xf08c;', 'styles' => array( 'sow-fab' ), ),
		'linkedin-in' => array( 'unicode' => '&#xf0e1;', 'styles' => array( 'sow-fab' ), ),
		'linode' => array( 'unicode' => '&#xf2b8;', 'styles' => array( 'sow-fab' ), ),
		'linux' => array( 'unicode' => '&#xf17c;', 'styles' => array( 'sow-fab' ), ),
		'lira-sign' => array( 'unicode' => '&#xf195;', 'styles' => array( 'sow-fas' ), ),
		'list' => array( 'unicode' => '&#xf03a;', 'styles' => array( 'sow-fas' ), ),
		'list-alt' => array( 'unicode' => '&#xf022;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'list-ol' => array( 'unicode' => '&#xf0cb;', 'styles' => array( 'sow-fas' ), ),
		'list-ul' => array( 'unicode' => '&#xf0ca;', 'styles' => array( 'sow-fas' ), ),
		'location-arrow' => array( 'unicode' => '&#xf124;', 'styles' => array( 'sow-fas' ), ),
		'lock' => array( 'unicode' => '&#xf023;', 'styles' => array( 'sow-fas' ), ),
		'lock-open' => array( 'unicode' => '&#xf3c1;', 'styles' => array( 'sow-fas' ), ),
		'long-arrow-alt-down' => array( 'unicode' => '&#xf309;', 'styles' => array( 'sow-fas' ), ),
		'long-arrow-alt-left' => array( 'unicode' => '&#xf30a;', 'styles' => array( 'sow-fas' ), ),
		'long-arrow-alt-right' => array( 'unicode' => '&#xf30b;', 'styles' => array( 'sow-fas' ), ),
		'long-arrow-alt-up' => array( 'unicode' => '&#xf30c;', 'styles' => array( 'sow-fas' ), ),
		'low-vision' => array( 'unicode' => '&#xf2a8;', 'styles' => array( 'sow-fas' ), ),
		'luggage-cart' => array( 'unicode' => '&#xf59d;', 'styles' => array( 'sow-fas' ), ),
		'lungs' => array( 'unicode' => '&#xf604;', 'styles' => array( 'sow-fas' ), ),
		'lungs-virus' => array( 'unicode' => '&#xe067;', 'styles' => array( 'sow-fas' ), ),
		'lyft' => array( 'unicode' => '&#xf3c3;', 'styles' => array( 'sow-fab' ), ),
		'magento' => array( 'unicode' => '&#xf3c4;', 'styles' => array( 'sow-fab' ), ),
		'magic' => array( 'unicode' => '&#xf0d0;', 'styles' => array( 'sow-fas' ), ),
		'magnet' => array( 'unicode' => '&#xf076;', 'styles' => array( 'sow-fas' ), ),
		'mail-bulk' => array( 'unicode' => '&#xf674;', 'styles' => array( 'sow-fas' ), ),
		'mailchimp' => array( 'unicode' => '&#xf59e;', 'styles' => array( 'sow-fab' ), ),
		'male' => array( 'unicode' => '&#xf183;', 'styles' => array( 'sow-fas' ), ),
		'mandalorian' => array( 'unicode' => '&#xf50f;', 'styles' => array( 'sow-fab' ), ),
		'map' => array( 'unicode' => '&#xf279;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'map-marked' => array( 'unicode' => '&#xf59f;', 'styles' => array( 'sow-fas' ), ),
		'map-marked-alt' => array( 'unicode' => '&#xf5a0;', 'styles' => array( 'sow-fas' ), ),
		'map-marker' => array( 'unicode' => '&#xf041;', 'styles' => array( 'sow-fas' ), ),
		'map-marker-alt' => array( 'unicode' => '&#xf3c5;', 'styles' => array( 'sow-fas' ), ),
		'map-pin' => array( 'unicode' => '&#xf276;', 'styles' => array( 'sow-fas' ), ),
		'map-signs' => array( 'unicode' => '&#xf277;', 'styles' => array( 'sow-fas' ), ),
		'markdown' => array( 'unicode' => '&#xf60f;', 'styles' => array( 'sow-fab' ), ),
		'marker' => array( 'unicode' => '&#xf5a1;', 'styles' => array( 'sow-fas' ), ),
		'mars' => array( 'unicode' => '&#xf222;', 'styles' => array( 'sow-fas' ), ),
		'mars-double' => array( 'unicode' => '&#xf227;', 'styles' => array( 'sow-fas' ), ),
		'mars-stroke' => array( 'unicode' => '&#xf229;', 'styles' => array( 'sow-fas' ), ),
		'mars-stroke-h' => array( 'unicode' => '&#xf22b;', 'styles' => array( 'sow-fas' ), ),
		'mars-stroke-v' => array( 'unicode' => '&#xf22a;', 'styles' => array( 'sow-fas' ), ),
		'mask' => array( 'unicode' => '&#xf6fa;', 'styles' => array( 'sow-fas' ), ),
		'mastodon' => array( 'unicode' => '&#xf4f6;', 'styles' => array( 'sow-fab' ), ),
		'maxcdn' => array( 'unicode' => '&#xf136;', 'styles' => array( 'sow-fab' ), ),
		'mdb' => array( 'unicode' => '&#xf8ca;', 'styles' => array( 'sow-fab' ), ),
		'medal' => array( 'unicode' => '&#xf5a2;', 'styles' => array( 'sow-fas' ), ),
		'medapps' => array( 'unicode' => '&#xf3c6;', 'styles' => array( 'sow-fab' ), ),
		'medium' => array( 'unicode' => '&#xf23a;', 'styles' => array( 'sow-fab' ), ),
		'medium-m' => array( 'unicode' => '&#xf3c7;', 'styles' => array( 'sow-fab' ), ),
		'medkit' => array( 'unicode' => '&#xf0fa;', 'styles' => array( 'sow-fas' ), ),
		'medrt' => array( 'unicode' => '&#xf3c8;', 'styles' => array( 'sow-fab' ), ),
		'meetup' => array( 'unicode' => '&#xf2e0;', 'styles' => array( 'sow-fab' ), ),
		'megaport' => array( 'unicode' => '&#xf5a3;', 'styles' => array( 'sow-fab' ), ),
		'meh' => array( 'unicode' => '&#xf11a;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'meh-blank' => array( 'unicode' => '&#xf5a4;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'meh-rolling-eyes' => array( 'unicode' => '&#xf5a5;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'memory' => array( 'unicode' => '&#xf538;', 'styles' => array( 'sow-fas' ), ),
		'mendeley' => array( 'unicode' => '&#xf7b3;', 'styles' => array( 'sow-fab' ), ),
		'menorah' => array( 'unicode' => '&#xf676;', 'styles' => array( 'sow-fas' ), ),
		'mercury' => array( 'unicode' => '&#xf223;', 'styles' => array( 'sow-fas' ), ),
		'meteor' => array( 'unicode' => '&#xf753;', 'styles' => array( 'sow-fas' ), ),
		'microblog' => array( 'unicode' => '&#xe01a;', 'styles' => array( 'sow-fab' ), ),
		'microchip' => array( 'unicode' => '&#xf2db;', 'styles' => array( 'sow-fas' ), ),
		'microphone' => array( 'unicode' => '&#xf130;', 'styles' => array( 'sow-fas' ), ),
		'microphone-alt' => array( 'unicode' => '&#xf3c9;', 'styles' => array( 'sow-fas' ), ),
		'microphone-alt-slash' => array( 'unicode' => '&#xf539;', 'styles' => array( 'sow-fas' ), ),
		'microphone-slash' => array( 'unicode' => '&#xf131;', 'styles' => array( 'sow-fas' ), ),
		'microscope' => array( 'unicode' => '&#xf610;', 'styles' => array( 'sow-fas' ), ),
		'microsoft' => array( 'unicode' => '&#xf3ca;', 'styles' => array( 'sow-fab' ), ),
		'minus' => array( 'unicode' => '&#xf068;', 'styles' => array( 'sow-fas' ), ),
		'minus-circle' => array( 'unicode' => '&#xf056;', 'styles' => array( 'sow-fas' ), ),
		'minus-square' => array( 'unicode' => '&#xf146;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'mitten' => array( 'unicode' => '&#xf7b5;', 'styles' => array( 'sow-fas' ), ),
		'mix' => array( 'unicode' => '&#xf3cb;', 'styles' => array( 'sow-fab' ), ),
		'mixcloud' => array( 'unicode' => '&#xf289;', 'styles' => array( 'sow-fab' ), ),
		'mixer' => array( 'unicode' => '&#xe056;', 'styles' => array( 'sow-fab' ), ),
		'mizuni' => array( 'unicode' => '&#xf3cc;', 'styles' => array( 'sow-fab' ), ),
		'mobile' => array( 'unicode' => '&#xf10b;', 'styles' => array( 'sow-fas' ), ),
		'mobile-alt' => array( 'unicode' => '&#xf3cd;', 'styles' => array( 'sow-fas' ), ),
		'modx' => array( 'unicode' => '&#xf285;', 'styles' => array( 'sow-fab' ), ),
		'monero' => array( 'unicode' => '&#xf3d0;', 'styles' => array( 'sow-fab' ), ),
		'money-bill' => array( 'unicode' => '&#xf0d6;', 'styles' => array( 'sow-fas' ), ),
		'money-bill-alt' => array( 'unicode' => '&#xf3d1;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'money-bill-wave' => array( 'unicode' => '&#xf53a;', 'styles' => array( 'sow-fas' ), ),
		'money-bill-wave-alt' => array( 'unicode' => '&#xf53b;', 'styles' => array( 'sow-fas' ), ),
		'money-check' => array( 'unicode' => '&#xf53c;', 'styles' => array( 'sow-fas' ), ),
		'money-check-alt' => array( 'unicode' => '&#xf53d;', 'styles' => array( 'sow-fas' ), ),
		'monument' => array( 'unicode' => '&#xf5a6;', 'styles' => array( 'sow-fas' ), ),
		'moon' => array( 'unicode' => '&#xf186;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'mortar-pestle' => array( 'unicode' => '&#xf5a7;', 'styles' => array( 'sow-fas' ), ),
		'mosque' => array( 'unicode' => '&#xf678;', 'styles' => array( 'sow-fas' ), ),
		'motorcycle' => array( 'unicode' => '&#xf21c;', 'styles' => array( 'sow-fas' ), ),
		'mountain' => array( 'unicode' => '&#xf6fc;', 'styles' => array( 'sow-fas' ), ),
		'mouse' => array( 'unicode' => '&#xf8cc;', 'styles' => array( 'sow-fas' ), ),
		'mouse-pointer' => array( 'unicode' => '&#xf245;', 'styles' => array( 'sow-fas' ), ),
		'mug-hot' => array( 'unicode' => '&#xf7b6;', 'styles' => array( 'sow-fas' ), ),
		'music' => array( 'unicode' => '&#xf001;', 'styles' => array( 'sow-fas' ), ),
		'napster' => array( 'unicode' => '&#xf3d2;', 'styles' => array( 'sow-fab' ), ),
		'neos' => array( 'unicode' => '&#xf612;', 'styles' => array( 'sow-fab' ), ),
		'network-wired' => array( 'unicode' => '&#xf6ff;', 'styles' => array( 'sow-fas' ), ),
		'neuter' => array( 'unicode' => '&#xf22c;', 'styles' => array( 'sow-fas' ), ),
		'newspaper' => array( 'unicode' => '&#xf1ea;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'nimblr' => array( 'unicode' => '&#xf5a8;', 'styles' => array( 'sow-fab' ), ),
		'node' => array( 'unicode' => '&#xf419;', 'styles' => array( 'sow-fab' ), ),
		'node-js' => array( 'unicode' => '&#xf3d3;', 'styles' => array( 'sow-fab' ), ),
		'not-equal' => array( 'unicode' => '&#xf53e;', 'styles' => array( 'sow-fas' ), ),
		'notes-medical' => array( 'unicode' => '&#xf481;', 'styles' => array( 'sow-fas' ), ),
		'npm' => array( 'unicode' => '&#xf3d4;', 'styles' => array( 'sow-fab' ), ),
		'ns8' => array( 'unicode' => '&#xf3d5;', 'styles' => array( 'sow-fab' ), ),
		'nutritionix' => array( 'unicode' => '&#xf3d6;', 'styles' => array( 'sow-fab' ), ),
		'object-group' => array( 'unicode' => '&#xf247;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'object-ungroup' => array( 'unicode' => '&#xf248;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'octopus-deploy' => array( 'unicode' => '&#xe082;', 'styles' => array( 'sow-fab' ), ),
		'odnoklassniki' => array( 'unicode' => '&#xf263;', 'styles' => array( 'sow-fab' ), ),
		'odnoklassniki-square' => array( 'unicode' => '&#xf264;', 'styles' => array( 'sow-fab' ), ),
		'oil-can' => array( 'unicode' => '&#xf613;', 'styles' => array( 'sow-fas' ), ),
		'old-republic' => array( 'unicode' => '&#xf510;', 'styles' => array( 'sow-fab' ), ),
		'om' => array( 'unicode' => '&#xf679;', 'styles' => array( 'sow-fas' ), ),
		'opencart' => array( 'unicode' => '&#xf23d;', 'styles' => array( 'sow-fab' ), ),
		'openid' => array( 'unicode' => '&#xf19b;', 'styles' => array( 'sow-fab' ), ),
		'opera' => array( 'unicode' => '&#xf26a;', 'styles' => array( 'sow-fab' ), ),
		'optin-monster' => array( 'unicode' => '&#xf23c;', 'styles' => array( 'sow-fab' ), ),
		'orcid' => array( 'unicode' => '&#xf8d2;', 'styles' => array( 'sow-fab' ), ),
		'osi' => array( 'unicode' => '&#xf41a;', 'styles' => array( 'sow-fab' ), ),
		'otter' => array( 'unicode' => '&#xf700;', 'styles' => array( 'sow-fas' ), ),
		'outdent' => array( 'unicode' => '&#xf03b;', 'styles' => array( 'sow-fas' ), ),
		'page4' => array( 'unicode' => '&#xf3d7;', 'styles' => array( 'sow-fab' ), ),
		'pagelines' => array( 'unicode' => '&#xf18c;', 'styles' => array( 'sow-fab' ), ),
		'pager' => array( 'unicode' => '&#xf815;', 'styles' => array( 'sow-fas' ), ),
		'paint-brush' => array( 'unicode' => '&#xf1fc;', 'styles' => array( 'sow-fas' ), ),
		'paint-roller' => array( 'unicode' => '&#xf5aa;', 'styles' => array( 'sow-fas' ), ),
		'palette' => array( 'unicode' => '&#xf53f;', 'styles' => array( 'sow-fas' ), ),
		'palfed' => array( 'unicode' => '&#xf3d8;', 'styles' => array( 'sow-fab' ), ),
		'pallet' => array( 'unicode' => '&#xf482;', 'styles' => array( 'sow-fas' ), ),
		'paper-plane' => array( 'unicode' => '&#xf1d8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'paperclip' => array( 'unicode' => '&#xf0c6;', 'styles' => array( 'sow-fas' ), ),
		'parachute-box' => array( 'unicode' => '&#xf4cd;', 'styles' => array( 'sow-fas' ), ),
		'paragraph' => array( 'unicode' => '&#xf1dd;', 'styles' => array( 'sow-fas' ), ),
		'parking' => array( 'unicode' => '&#xf540;', 'styles' => array( 'sow-fas' ), ),
		'passport' => array( 'unicode' => '&#xf5ab;', 'styles' => array( 'sow-fas' ), ),
		'pastafarianism' => array( 'unicode' => '&#xf67b;', 'styles' => array( 'sow-fas' ), ),
		'paste' => array( 'unicode' => '&#xf0ea;', 'styles' => array( 'sow-fas' ), ),
		'patreon' => array( 'unicode' => '&#xf3d9;', 'styles' => array( 'sow-fab' ), ),
		'pause' => array( 'unicode' => '&#xf04c;', 'styles' => array( 'sow-fas' ), ),
		'pause-circle' => array( 'unicode' => '&#xf28b;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'paw' => array( 'unicode' => '&#xf1b0;', 'styles' => array( 'sow-fas' ), ),
		'paypal' => array( 'unicode' => '&#xf1ed;', 'styles' => array( 'sow-fab' ), ),
		'peace' => array( 'unicode' => '&#xf67c;', 'styles' => array( 'sow-fas' ), ),
		'pen' => array( 'unicode' => '&#xf304;', 'styles' => array( 'sow-fas' ), ),
		'pen-alt' => array( 'unicode' => '&#xf305;', 'styles' => array( 'sow-fas' ), ),
		'pen-fancy' => array( 'unicode' => '&#xf5ac;', 'styles' => array( 'sow-fas' ), ),
		'pen-nib' => array( 'unicode' => '&#xf5ad;', 'styles' => array( 'sow-fas' ), ),
		'pen-square' => array( 'unicode' => '&#xf14b;', 'styles' => array( 'sow-fas' ), ),
		'pencil-alt' => array( 'unicode' => '&#xf303;', 'styles' => array( 'sow-fas' ), ),
		'pencil-ruler' => array( 'unicode' => '&#xf5ae;', 'styles' => array( 'sow-fas' ), ),
		'penny-arcade' => array( 'unicode' => '&#xf704;', 'styles' => array( 'sow-fab' ), ),
		'people-arrows' => array( 'unicode' => '&#xe068;', 'styles' => array( 'sow-fas' ), ),
		'people-carry' => array( 'unicode' => '&#xf4ce;', 'styles' => array( 'sow-fas' ), ),
		'pepper-hot' => array( 'unicode' => '&#xf816;', 'styles' => array( 'sow-fas' ), ),
		'perbyte' => array( 'unicode' => '&#xe083;', 'styles' => array( 'sow-fab' ), ),
		'percent' => array( 'unicode' => '&#xf295;', 'styles' => array( 'sow-fas' ), ),
		'percentage' => array( 'unicode' => '&#xf541;', 'styles' => array( 'sow-fas' ), ),
		'periscope' => array( 'unicode' => '&#xf3da;', 'styles' => array( 'sow-fab' ), ),
		'person-booth' => array( 'unicode' => '&#xf756;', 'styles' => array( 'sow-fas' ), ),
		'phabricator' => array( 'unicode' => '&#xf3db;', 'styles' => array( 'sow-fab' ), ),
		'phoenix-framework' => array( 'unicode' => '&#xf3dc;', 'styles' => array( 'sow-fab' ), ),
		'phoenix-squadron' => array( 'unicode' => '&#xf511;', 'styles' => array( 'sow-fab' ), ),
		'phone' => array( 'unicode' => '&#xf095;', 'styles' => array( 'sow-fas' ), ),
		'phone-alt' => array( 'unicode' => '&#xf879;', 'styles' => array( 'sow-fas' ), ),
		'phone-slash' => array( 'unicode' => '&#xf3dd;', 'styles' => array( 'sow-fas' ), ),
		'phone-square' => array( 'unicode' => '&#xf098;', 'styles' => array( 'sow-fas' ), ),
		'phone-square-alt' => array( 'unicode' => '&#xf87b;', 'styles' => array( 'sow-fas' ), ),
		'phone-volume' => array( 'unicode' => '&#xf2a0;', 'styles' => array( 'sow-fas' ), ),
		'photo-video' => array( 'unicode' => '&#xf87c;', 'styles' => array( 'sow-fas' ), ),
		'php' => array( 'unicode' => '&#xf457;', 'styles' => array( 'sow-fab' ), ),
		'pied-piper' => array( 'unicode' => '&#xf2ae;', 'styles' => array( 'sow-fab' ), ),
		'pied-piper-alt' => array( 'unicode' => '&#xf1a8;', 'styles' => array( 'sow-fab' ), ),
		'pied-piper-hat' => array( 'unicode' => '&#xf4e5;', 'styles' => array( 'sow-fab' ), ),
		'pied-piper-pp' => array( 'unicode' => '&#xf1a7;', 'styles' => array( 'sow-fab' ), ),
		'pied-piper-square' => array( 'unicode' => '&#xe01e;', 'styles' => array( 'sow-fab' ), ),
		'piggy-bank' => array( 'unicode' => '&#xf4d3;', 'styles' => array( 'sow-fas' ), ),
		'pills' => array( 'unicode' => '&#xf484;', 'styles' => array( 'sow-fas' ), ),
		'pinterest' => array( 'unicode' => '&#xf0d2;', 'styles' => array( 'sow-fab' ), ),
		'pinterest-p' => array( 'unicode' => '&#xf231;', 'styles' => array( 'sow-fab' ), ),
		'pinterest-square' => array( 'unicode' => '&#xf0d3;', 'styles' => array( 'sow-fab' ), ),
		'pizza-slice' => array( 'unicode' => '&#xf818;', 'styles' => array( 'sow-fas' ), ),
		'place-of-worship' => array( 'unicode' => '&#xf67f;', 'styles' => array( 'sow-fas' ), ),
		'plane' => array( 'unicode' => '&#xf072;', 'styles' => array( 'sow-fas' ), ),
		'plane-arrival' => array( 'unicode' => '&#xf5af;', 'styles' => array( 'sow-fas' ), ),
		'plane-departure' => array( 'unicode' => '&#xf5b0;', 'styles' => array( 'sow-fas' ), ),
		'plane-slash' => array( 'unicode' => '&#xe069;', 'styles' => array( 'sow-fas' ), ),
		'play' => array( 'unicode' => '&#xf04b;', 'styles' => array( 'sow-fas' ), ),
		'play-circle' => array( 'unicode' => '&#xf144;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'playstation' => array( 'unicode' => '&#xf3df;', 'styles' => array( 'sow-fab' ), ),
		'plug' => array( 'unicode' => '&#xf1e6;', 'styles' => array( 'sow-fas' ), ),
		'plus' => array( 'unicode' => '&#xf067;', 'styles' => array( 'sow-fas' ), ),
		'plus-circle' => array( 'unicode' => '&#xf055;', 'styles' => array( 'sow-fas' ), ),
		'plus-square' => array( 'unicode' => '&#xf0fe;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'podcast' => array( 'unicode' => '&#xf2ce;', 'styles' => array( 'sow-fas' ), ),
		'poll' => array( 'unicode' => '&#xf681;', 'styles' => array( 'sow-fas' ), ),
		'poll-h' => array( 'unicode' => '&#xf682;', 'styles' => array( 'sow-fas' ), ),
		'poo' => array( 'unicode' => '&#xf2fe;', 'styles' => array( 'sow-fas' ), ),
		'poo-storm' => array( 'unicode' => '&#xf75a;', 'styles' => array( 'sow-fas' ), ),
		'poop' => array( 'unicode' => '&#xf619;', 'styles' => array( 'sow-fas' ), ),
		'portrait' => array( 'unicode' => '&#xf3e0;', 'styles' => array( 'sow-fas' ), ),
		'pound-sign' => array( 'unicode' => '&#xf154;', 'styles' => array( 'sow-fas' ), ),
		'power-off' => array( 'unicode' => '&#xf011;', 'styles' => array( 'sow-fas' ), ),
		'pray' => array( 'unicode' => '&#xf683;', 'styles' => array( 'sow-fas' ), ),
		'praying-hands' => array( 'unicode' => '&#xf684;', 'styles' => array( 'sow-fas' ), ),
		'prescription' => array( 'unicode' => '&#xf5b1;', 'styles' => array( 'sow-fas' ), ),
		'prescription-bottle' => array( 'unicode' => '&#xf485;', 'styles' => array( 'sow-fas' ), ),
		'prescription-bottle-alt' => array( 'unicode' => '&#xf486;', 'styles' => array( 'sow-fas' ), ),
		'print' => array( 'unicode' => '&#xf02f;', 'styles' => array( 'sow-fas' ), ),
		'procedures' => array( 'unicode' => '&#xf487;', 'styles' => array( 'sow-fas' ), ),
		'product-hunt' => array( 'unicode' => '&#xf288;', 'styles' => array( 'sow-fab' ), ),
		'project-diagram' => array( 'unicode' => '&#xf542;', 'styles' => array( 'sow-fas' ), ),
		'pump-medical' => array( 'unicode' => '&#xe06a;', 'styles' => array( 'sow-fas' ), ),
		'pump-soap' => array( 'unicode' => '&#xe06b;', 'styles' => array( 'sow-fas' ), ),
		'pushed' => array( 'unicode' => '&#xf3e1;', 'styles' => array( 'sow-fab' ), ),
		'puzzle-piece' => array( 'unicode' => '&#xf12e;', 'styles' => array( 'sow-fas' ), ),
		'python' => array( 'unicode' => '&#xf3e2;', 'styles' => array( 'sow-fab' ), ),
		'qq' => array( 'unicode' => '&#xf1d6;', 'styles' => array( 'sow-fab' ), ),
		'qrcode' => array( 'unicode' => '&#xf029;', 'styles' => array( 'sow-fas' ), ),
		'question' => array( 'unicode' => '&#xf128;', 'styles' => array( 'sow-fas' ), ),
		'question-circle' => array( 'unicode' => '&#xf059;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'quidditch' => array( 'unicode' => '&#xf458;', 'styles' => array( 'sow-fas' ), ),
		'quinscape' => array( 'unicode' => '&#xf459;', 'styles' => array( 'sow-fab' ), ),
		'quora' => array( 'unicode' => '&#xf2c4;', 'styles' => array( 'sow-fab' ), ),
		'quote-left' => array( 'unicode' => '&#xf10d;', 'styles' => array( 'sow-fas' ), ),
		'quote-right' => array( 'unicode' => '&#xf10e;', 'styles' => array( 'sow-fas' ), ),
		'quran' => array( 'unicode' => '&#xf687;', 'styles' => array( 'sow-fas' ), ),
		'r-project' => array( 'unicode' => '&#xf4f7;', 'styles' => array( 'sow-fab' ), ),
		'radiation' => array( 'unicode' => '&#xf7b9;', 'styles' => array( 'sow-fas' ), ),
		'radiation-alt' => array( 'unicode' => '&#xf7ba;', 'styles' => array( 'sow-fas' ), ),
		'rainbow' => array( 'unicode' => '&#xf75b;', 'styles' => array( 'sow-fas' ), ),
		'random' => array( 'unicode' => '&#xf074;', 'styles' => array( 'sow-fas' ), ),
		'raspberry-pi' => array( 'unicode' => '&#xf7bb;', 'styles' => array( 'sow-fab' ), ),
		'ravelry' => array( 'unicode' => '&#xf2d9;', 'styles' => array( 'sow-fab' ), ),
		'react' => array( 'unicode' => '&#xf41b;', 'styles' => array( 'sow-fab' ), ),
		'reacteurope' => array( 'unicode' => '&#xf75d;', 'styles' => array( 'sow-fab' ), ),
		'readme' => array( 'unicode' => '&#xf4d5;', 'styles' => array( 'sow-fab' ), ),
		'rebel' => array( 'unicode' => '&#xf1d0;', 'styles' => array( 'sow-fab' ), ),
		'receipt' => array( 'unicode' => '&#xf543;', 'styles' => array( 'sow-fas' ), ),
		'record-vinyl' => array( 'unicode' => '&#xf8d9;', 'styles' => array( 'sow-fas' ), ),
		'recycle' => array( 'unicode' => '&#xf1b8;', 'styles' => array( 'sow-fas' ), ),
		'red-river' => array( 'unicode' => '&#xf3e3;', 'styles' => array( 'sow-fab' ), ),
		'reddit' => array( 'unicode' => '&#xf1a1;', 'styles' => array( 'sow-fab' ), ),
		'reddit-alien' => array( 'unicode' => '&#xf281;', 'styles' => array( 'sow-fab' ), ),
		'reddit-square' => array( 'unicode' => '&#xf1a2;', 'styles' => array( 'sow-fab' ), ),
		'redhat' => array( 'unicode' => '&#xf7bc;', 'styles' => array( 'sow-fab' ), ),
		'redo' => array( 'unicode' => '&#xf01e;', 'styles' => array( 'sow-fas' ), ),
		'redo-alt' => array( 'unicode' => '&#xf2f9;', 'styles' => array( 'sow-fas' ), ),
		'registered' => array( 'unicode' => '&#xf25d;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'remove-format' => array( 'unicode' => '&#xf87d;', 'styles' => array( 'sow-fas' ), ),
		'renren' => array( 'unicode' => '&#xf18b;', 'styles' => array( 'sow-fab' ), ),
		'reply' => array( 'unicode' => '&#xf3e5;', 'styles' => array( 'sow-fas' ), ),
		'reply-all' => array( 'unicode' => '&#xf122;', 'styles' => array( 'sow-fas' ), ),
		'replyd' => array( 'unicode' => '&#xf3e6;', 'styles' => array( 'sow-fab' ), ),
		'republican' => array( 'unicode' => '&#xf75e;', 'styles' => array( 'sow-fas' ), ),
		'researchgate' => array( 'unicode' => '&#xf4f8;', 'styles' => array( 'sow-fab' ), ),
		'resolving' => array( 'unicode' => '&#xf3e7;', 'styles' => array( 'sow-fab' ), ),
		'restroom' => array( 'unicode' => '&#xf7bd;', 'styles' => array( 'sow-fas' ), ),
		'retweet' => array( 'unicode' => '&#xf079;', 'styles' => array( 'sow-fas' ), ),
		'rev' => array( 'unicode' => '&#xf5b2;', 'styles' => array( 'sow-fab' ), ),
		'ribbon' => array( 'unicode' => '&#xf4d6;', 'styles' => array( 'sow-fas' ), ),
		'ring' => array( 'unicode' => '&#xf70b;', 'styles' => array( 'sow-fas' ), ),
		'road' => array( 'unicode' => '&#xf018;', 'styles' => array( 'sow-fas' ), ),
		'robot' => array( 'unicode' => '&#xf544;', 'styles' => array( 'sow-fas' ), ),
		'rocket' => array( 'unicode' => '&#xf135;', 'styles' => array( 'sow-fas' ), ),
		'rocketchat' => array( 'unicode' => '&#xf3e8;', 'styles' => array( 'sow-fab' ), ),
		'rockrms' => array( 'unicode' => '&#xf3e9;', 'styles' => array( 'sow-fab' ), ),
		'route' => array( 'unicode' => '&#xf4d7;', 'styles' => array( 'sow-fas' ), ),
		'rss' => array( 'unicode' => '&#xf09e;', 'styles' => array( 'sow-fas' ), ),
		'rss-square' => array( 'unicode' => '&#xf143;', 'styles' => array( 'sow-fas' ), ),
		'ruble-sign' => array( 'unicode' => '&#xf158;', 'styles' => array( 'sow-fas' ), ),
		'ruler' => array( 'unicode' => '&#xf545;', 'styles' => array( 'sow-fas' ), ),
		'ruler-combined' => array( 'unicode' => '&#xf546;', 'styles' => array( 'sow-fas' ), ),
		'ruler-horizontal' => array( 'unicode' => '&#xf547;', 'styles' => array( 'sow-fas' ), ),
		'ruler-vertical' => array( 'unicode' => '&#xf548;', 'styles' => array( 'sow-fas' ), ),
		'running' => array( 'unicode' => '&#xf70c;', 'styles' => array( 'sow-fas' ), ),
		'rupee-sign' => array( 'unicode' => '&#xf156;', 'styles' => array( 'sow-fas' ), ),
		'rust' => array( 'unicode' => '&#xe07a;', 'styles' => array( 'sow-fab' ), ),
		'sad-cry' => array( 'unicode' => '&#xf5b3;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'sad-tear' => array( 'unicode' => '&#xf5b4;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'safari' => array( 'unicode' => '&#xf267;', 'styles' => array( 'sow-fab' ), ),
		'salesforce' => array( 'unicode' => '&#xf83b;', 'styles' => array( 'sow-fab' ), ),
		'sass' => array( 'unicode' => '&#xf41e;', 'styles' => array( 'sow-fab' ), ),
		'satellite' => array( 'unicode' => '&#xf7bf;', 'styles' => array( 'sow-fas' ), ),
		'satellite-dish' => array( 'unicode' => '&#xf7c0;', 'styles' => array( 'sow-fas' ), ),
		'save' => array( 'unicode' => '&#xf0c7;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'schlix' => array( 'unicode' => '&#xf3ea;', 'styles' => array( 'sow-fab' ), ),
		'school' => array( 'unicode' => '&#xf549;', 'styles' => array( 'sow-fas' ), ),
		'screwdriver' => array( 'unicode' => '&#xf54a;', 'styles' => array( 'sow-fas' ), ),
		'scribd' => array( 'unicode' => '&#xf28a;', 'styles' => array( 'sow-fab' ), ),
		'scroll' => array( 'unicode' => '&#xf70e;', 'styles' => array( 'sow-fas' ), ),
		'sd-card' => array( 'unicode' => '&#xf7c2;', 'styles' => array( 'sow-fas' ), ),
		'search' => array( 'unicode' => '&#xf002;', 'styles' => array( 'sow-fas' ), ),
		'search-dollar' => array( 'unicode' => '&#xf688;', 'styles' => array( 'sow-fas' ), ),
		'search-location' => array( 'unicode' => '&#xf689;', 'styles' => array( 'sow-fas' ), ),
		'search-minus' => array( 'unicode' => '&#xf010;', 'styles' => array( 'sow-fas' ), ),
		'search-plus' => array( 'unicode' => '&#xf00e;', 'styles' => array( 'sow-fas' ), ),
		'searchengin' => array( 'unicode' => '&#xf3eb;', 'styles' => array( 'sow-fab' ), ),
		'seedling' => array( 'unicode' => '&#xf4d8;', 'styles' => array( 'sow-fas' ), ),
		'sellcast' => array( 'unicode' => '&#xf2da;', 'styles' => array( 'sow-fab' ), ),
		'sellsy' => array( 'unicode' => '&#xf213;', 'styles' => array( 'sow-fab' ), ),
		'server' => array( 'unicode' => '&#xf233;', 'styles' => array( 'sow-fas' ), ),
		'servicestack' => array( 'unicode' => '&#xf3ec;', 'styles' => array( 'sow-fab' ), ),
		'shapes' => array( 'unicode' => '&#xf61f;', 'styles' => array( 'sow-fas' ), ),
		'share' => array( 'unicode' => '&#xf064;', 'styles' => array( 'sow-fas' ), ),
		'share-alt' => array( 'unicode' => '&#xf1e0;', 'styles' => array( 'sow-fas' ), ),
		'share-alt-square' => array( 'unicode' => '&#xf1e1;', 'styles' => array( 'sow-fas' ), ),
		'share-square' => array( 'unicode' => '&#xf14d;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'shekel-sign' => array( 'unicode' => '&#xf20b;', 'styles' => array( 'sow-fas' ), ),
		'shield-alt' => array( 'unicode' => '&#xf3ed;', 'styles' => array( 'sow-fas' ), ),
		'shield-virus' => array( 'unicode' => '&#xe06c;', 'styles' => array( 'sow-fas' ), ),
		'ship' => array( 'unicode' => '&#xf21a;', 'styles' => array( 'sow-fas' ), ),
		'shipping-fast' => array( 'unicode' => '&#xf48b;', 'styles' => array( 'sow-fas' ), ),
		'shirtsinbulk' => array( 'unicode' => '&#xf214;', 'styles' => array( 'sow-fab' ), ),
		'shoe-prints' => array( 'unicode' => '&#xf54b;', 'styles' => array( 'sow-fas' ), ),
		'shopify' => array( 'unicode' => '&#xe057;', 'styles' => array( 'sow-fab' ), ),
		'shopping-bag' => array( 'unicode' => '&#xf290;', 'styles' => array( 'sow-fas' ), ),
		'shopping-basket' => array( 'unicode' => '&#xf291;', 'styles' => array( 'sow-fas' ), ),
		'shopping-cart' => array( 'unicode' => '&#xf07a;', 'styles' => array( 'sow-fas' ), ),
		'shopware' => array( 'unicode' => '&#xf5b5;', 'styles' => array( 'sow-fab' ), ),
		'shower' => array( 'unicode' => '&#xf2cc;', 'styles' => array( 'sow-fas' ), ),
		'shuttle-van' => array( 'unicode' => '&#xf5b6;', 'styles' => array( 'sow-fas' ), ),
		'sign' => array( 'unicode' => '&#xf4d9;', 'styles' => array( 'sow-fas' ), ),
		'sign-in-alt' => array( 'unicode' => '&#xf2f6;', 'styles' => array( 'sow-fas' ), ),
		'sign-language' => array( 'unicode' => '&#xf2a7;', 'styles' => array( 'sow-fas' ), ),
		'sign-out-alt' => array( 'unicode' => '&#xf2f5;', 'styles' => array( 'sow-fas' ), ),
		'signal' => array( 'unicode' => '&#xf012;', 'styles' => array( 'sow-fas' ), ),
		'signature' => array( 'unicode' => '&#xf5b7;', 'styles' => array( 'sow-fas' ), ),
		'sim-card' => array( 'unicode' => '&#xf7c4;', 'styles' => array( 'sow-fas' ), ),
		'simplybuilt' => array( 'unicode' => '&#xf215;', 'styles' => array( 'sow-fab' ), ),
		'sink' => array( 'unicode' => '&#xe06d;', 'styles' => array( 'sow-fas' ), ),
		'sistrix' => array( 'unicode' => '&#xf3ee;', 'styles' => array( 'sow-fab' ), ),
		'sitemap' => array( 'unicode' => '&#xf0e8;', 'styles' => array( 'sow-fas' ), ),
		'sith' => array( 'unicode' => '&#xf512;', 'styles' => array( 'sow-fab' ), ),
		'skating' => array( 'unicode' => '&#xf7c5;', 'styles' => array( 'sow-fas' ), ),
		'sketch' => array( 'unicode' => '&#xf7c6;', 'styles' => array( 'sow-fab' ), ),
		'skiing' => array( 'unicode' => '&#xf7c9;', 'styles' => array( 'sow-fas' ), ),
		'skiing-nordic' => array( 'unicode' => '&#xf7ca;', 'styles' => array( 'sow-fas' ), ),
		'skull' => array( 'unicode' => '&#xf54c;', 'styles' => array( 'sow-fas' ), ),
		'skull-crossbones' => array( 'unicode' => '&#xf714;', 'styles' => array( 'sow-fas' ), ),
		'skyatlas' => array( 'unicode' => '&#xf216;', 'styles' => array( 'sow-fab' ), ),
		'skype' => array( 'unicode' => '&#xf17e;', 'styles' => array( 'sow-fab' ), ),
		'slack' => array( 'unicode' => '&#xf198;', 'styles' => array( 'sow-fab' ), ),
		'slack-hash' => array( 'unicode' => '&#xf3ef;', 'styles' => array( 'sow-fab' ), ),
		'slash' => array( 'unicode' => '&#xf715;', 'styles' => array( 'sow-fas' ), ),
		'sleigh' => array( 'unicode' => '&#xf7cc;', 'styles' => array( 'sow-fas' ), ),
		'sliders-h' => array( 'unicode' => '&#xf1de;', 'styles' => array( 'sow-fas' ), ),
		'slideshare' => array( 'unicode' => '&#xf1e7;', 'styles' => array( 'sow-fab' ), ),
		'smile' => array( 'unicode' => '&#xf118;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'smile-beam' => array( 'unicode' => '&#xf5b8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'smile-wink' => array( 'unicode' => '&#xf4da;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'smog' => array( 'unicode' => '&#xf75f;', 'styles' => array( 'sow-fas' ), ),
		'smoking' => array( 'unicode' => '&#xf48d;', 'styles' => array( 'sow-fas' ), ),
		'smoking-ban' => array( 'unicode' => '&#xf54d;', 'styles' => array( 'sow-fas' ), ),
		'sms' => array( 'unicode' => '&#xf7cd;', 'styles' => array( 'sow-fas' ), ),
		'snapchat' => array( 'unicode' => '&#xf2ab;', 'styles' => array( 'sow-fab' ), ),
		'snapchat-ghost' => array( 'unicode' => '&#xf2ac;', 'styles' => array( 'sow-fab' ), ),
		'snapchat-square' => array( 'unicode' => '&#xf2ad;', 'styles' => array( 'sow-fab' ), ),
		'snowboarding' => array( 'unicode' => '&#xf7ce;', 'styles' => array( 'sow-fas' ), ),
		'snowflake' => array( 'unicode' => '&#xf2dc;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'snowman' => array( 'unicode' => '&#xf7d0;', 'styles' => array( 'sow-fas' ), ),
		'snowplow' => array( 'unicode' => '&#xf7d2;', 'styles' => array( 'sow-fas' ), ),
		'soap' => array( 'unicode' => '&#xe06e;', 'styles' => array( 'sow-fas' ), ),
		'socks' => array( 'unicode' => '&#xf696;', 'styles' => array( 'sow-fas' ), ),
		'solar-panel' => array( 'unicode' => '&#xf5ba;', 'styles' => array( 'sow-fas' ), ),
		'sort' => array( 'unicode' => '&#xf0dc;', 'styles' => array( 'sow-fas' ), ),
		'sort-alpha-down' => array( 'unicode' => '&#xf15d;', 'styles' => array( 'sow-fas' ), ),
		'sort-alpha-down-alt' => array( 'unicode' => '&#xf881;', 'styles' => array( 'sow-fas' ), ),
		'sort-alpha-up' => array( 'unicode' => '&#xf15e;', 'styles' => array( 'sow-fas' ), ),
		'sort-alpha-up-alt' => array( 'unicode' => '&#xf882;', 'styles' => array( 'sow-fas' ), ),
		'sort-amount-down' => array( 'unicode' => '&#xf160;', 'styles' => array( 'sow-fas' ), ),
		'sort-amount-down-alt' => array( 'unicode' => '&#xf884;', 'styles' => array( 'sow-fas' ), ),
		'sort-amount-up' => array( 'unicode' => '&#xf161;', 'styles' => array( 'sow-fas' ), ),
		'sort-amount-up-alt' => array( 'unicode' => '&#xf885;', 'styles' => array( 'sow-fas' ), ),
		'sort-down' => array( 'unicode' => '&#xf0dd;', 'styles' => array( 'sow-fas' ), ),
		'sort-numeric-down' => array( 'unicode' => '&#xf162;', 'styles' => array( 'sow-fas' ), ),
		'sort-numeric-down-alt' => array( 'unicode' => '&#xf886;', 'styles' => array( 'sow-fas' ), ),
		'sort-numeric-up' => array( 'unicode' => '&#xf163;', 'styles' => array( 'sow-fas' ), ),
		'sort-numeric-up-alt' => array( 'unicode' => '&#xf887;', 'styles' => array( 'sow-fas' ), ),
		'sort-up' => array( 'unicode' => '&#xf0de;', 'styles' => array( 'sow-fas' ), ),
		'soundcloud' => array( 'unicode' => '&#xf1be;', 'styles' => array( 'sow-fab' ), ),
		'sourcetree' => array( 'unicode' => '&#xf7d3;', 'styles' => array( 'sow-fab' ), ),
		'spa' => array( 'unicode' => '&#xf5bb;', 'styles' => array( 'sow-fas' ), ),
		'space-shuttle' => array( 'unicode' => '&#xf197;', 'styles' => array( 'sow-fas' ), ),
		'speakap' => array( 'unicode' => '&#xf3f3;', 'styles' => array( 'sow-fab' ), ),
		'speaker-deck' => array( 'unicode' => '&#xf83c;', 'styles' => array( 'sow-fab' ), ),
		'spell-check' => array( 'unicode' => '&#xf891;', 'styles' => array( 'sow-fas' ), ),
		'spider' => array( 'unicode' => '&#xf717;', 'styles' => array( 'sow-fas' ), ),
		'spinner' => array( 'unicode' => '&#xf110;', 'styles' => array( 'sow-fas' ), ),
		'splotch' => array( 'unicode' => '&#xf5bc;', 'styles' => array( 'sow-fas' ), ),
		'spotify' => array( 'unicode' => '&#xf1bc;', 'styles' => array( 'sow-fab' ), ),
		'spray-can' => array( 'unicode' => '&#xf5bd;', 'styles' => array( 'sow-fas' ), ),
		'square' => array( 'unicode' => '&#xf0c8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'square-full' => array( 'unicode' => '&#xf45c;', 'styles' => array( 'sow-fas' ), ),
		'square-root-alt' => array( 'unicode' => '&#xf698;', 'styles' => array( 'sow-fas' ), ),
		'squarespace' => array( 'unicode' => '&#xf5be;', 'styles' => array( 'sow-fab' ), ),
		'stack-exchange' => array( 'unicode' => '&#xf18d;', 'styles' => array( 'sow-fab' ), ),
		'stack-overflow' => array( 'unicode' => '&#xf16c;', 'styles' => array( 'sow-fab' ), ),
		'stackpath' => array( 'unicode' => '&#xf842;', 'styles' => array( 'sow-fab' ), ),
		'stamp' => array( 'unicode' => '&#xf5bf;', 'styles' => array( 'sow-fas' ), ),
		'star' => array( 'unicode' => '&#xf005;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'star-and-crescent' => array( 'unicode' => '&#xf699;', 'styles' => array( 'sow-fas' ), ),
		'star-half' => array( 'unicode' => '&#xf089;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'star-half-alt' => array( 'unicode' => '&#xf5c0;', 'styles' => array( 'sow-fas' ), ),
		'star-of-david' => array( 'unicode' => '&#xf69a;', 'styles' => array( 'sow-fas' ), ),
		'star-of-life' => array( 'unicode' => '&#xf621;', 'styles' => array( 'sow-fas' ), ),
		'staylinked' => array( 'unicode' => '&#xf3f5;', 'styles' => array( 'sow-fab' ), ),
		'steam' => array( 'unicode' => '&#xf1b6;', 'styles' => array( 'sow-fab' ), ),
		'steam-square' => array( 'unicode' => '&#xf1b7;', 'styles' => array( 'sow-fab' ), ),
		'steam-symbol' => array( 'unicode' => '&#xf3f6;', 'styles' => array( 'sow-fab' ), ),
		'step-backward' => array( 'unicode' => '&#xf048;', 'styles' => array( 'sow-fas' ), ),
		'step-forward' => array( 'unicode' => '&#xf051;', 'styles' => array( 'sow-fas' ), ),
		'stethoscope' => array( 'unicode' => '&#xf0f1;', 'styles' => array( 'sow-fas' ), ),
		'sticker-mule' => array( 'unicode' => '&#xf3f7;', 'styles' => array( 'sow-fab' ), ),
		'sticky-note' => array( 'unicode' => '&#xf249;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'stop' => array( 'unicode' => '&#xf04d;', 'styles' => array( 'sow-fas' ), ),
		'stop-circle' => array( 'unicode' => '&#xf28d;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'stopwatch' => array( 'unicode' => '&#xf2f2;', 'styles' => array( 'sow-fas' ), ),
		'stopwatch-20' => array( 'unicode' => '&#xe06f;', 'styles' => array( 'sow-fas' ), ),
		'store' => array( 'unicode' => '&#xf54e;', 'styles' => array( 'sow-fas' ), ),
		'store-alt' => array( 'unicode' => '&#xf54f;', 'styles' => array( 'sow-fas' ), ),
		'store-alt-slash' => array( 'unicode' => '&#xe070;', 'styles' => array( 'sow-fas' ), ),
		'store-slash' => array( 'unicode' => '&#xe071;', 'styles' => array( 'sow-fas' ), ),
		'strava' => array( 'unicode' => '&#xf428;', 'styles' => array( 'sow-fab' ), ),
		'stream' => array( 'unicode' => '&#xf550;', 'styles' => array( 'sow-fas' ), ),
		'street-view' => array( 'unicode' => '&#xf21d;', 'styles' => array( 'sow-fas' ), ),
		'strikethrough' => array( 'unicode' => '&#xf0cc;', 'styles' => array( 'sow-fas' ), ),
		'stripe' => array( 'unicode' => '&#xf429;', 'styles' => array( 'sow-fab' ), ),
		'stripe-s' => array( 'unicode' => '&#xf42a;', 'styles' => array( 'sow-fab' ), ),
		'stroopwafel' => array( 'unicode' => '&#xf551;', 'styles' => array( 'sow-fas' ), ),
		'studiovinari' => array( 'unicode' => '&#xf3f8;', 'styles' => array( 'sow-fab' ), ),
		'stumbleupon' => array( 'unicode' => '&#xf1a4;', 'styles' => array( 'sow-fab' ), ),
		'stumbleupon-circle' => array( 'unicode' => '&#xf1a3;', 'styles' => array( 'sow-fab' ), ),
		'subscript' => array( 'unicode' => '&#xf12c;', 'styles' => array( 'sow-fas' ), ),
		'subway' => array( 'unicode' => '&#xf239;', 'styles' => array( 'sow-fas' ), ),
		'suitcase' => array( 'unicode' => '&#xf0f2;', 'styles' => array( 'sow-fas' ), ),
		'suitcase-rolling' => array( 'unicode' => '&#xf5c1;', 'styles' => array( 'sow-fas' ), ),
		'sun' => array( 'unicode' => '&#xf185;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'superpowers' => array( 'unicode' => '&#xf2dd;', 'styles' => array( 'sow-fab' ), ),
		'superscript' => array( 'unicode' => '&#xf12b;', 'styles' => array( 'sow-fas' ), ),
		'supple' => array( 'unicode' => '&#xf3f9;', 'styles' => array( 'sow-fab' ), ),
		'surprise' => array( 'unicode' => '&#xf5c2;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'suse' => array( 'unicode' => '&#xf7d6;', 'styles' => array( 'sow-fab' ), ),
		'swatchbook' => array( 'unicode' => '&#xf5c3;', 'styles' => array( 'sow-fas' ), ),
		'swift' => array( 'unicode' => '&#xf8e1;', 'styles' => array( 'sow-fab' ), ),
		'swimmer' => array( 'unicode' => '&#xf5c4;', 'styles' => array( 'sow-fas' ), ),
		'swimming-pool' => array( 'unicode' => '&#xf5c5;', 'styles' => array( 'sow-fas' ), ),
		'symfony' => array( 'unicode' => '&#xf83d;', 'styles' => array( 'sow-fab' ), ),
		'synagogue' => array( 'unicode' => '&#xf69b;', 'styles' => array( 'sow-fas' ), ),
		'sync' => array( 'unicode' => '&#xf021;', 'styles' => array( 'sow-fas' ), ),
		'sync-alt' => array( 'unicode' => '&#xf2f1;', 'styles' => array( 'sow-fas' ), ),
		'syringe' => array( 'unicode' => '&#xf48e;', 'styles' => array( 'sow-fas' ), ),
		'table' => array( 'unicode' => '&#xf0ce;', 'styles' => array( 'sow-fas' ), ),
		'table-tennis' => array( 'unicode' => '&#xf45d;', 'styles' => array( 'sow-fas' ), ),
		'tablet' => array( 'unicode' => '&#xf10a;', 'styles' => array( 'sow-fas' ), ),
		'tablet-alt' => array( 'unicode' => '&#xf3fa;', 'styles' => array( 'sow-fas' ), ),
		'tablets' => array( 'unicode' => '&#xf490;', 'styles' => array( 'sow-fas' ), ),
		'tachometer-alt' => array( 'unicode' => '&#xf3fd;', 'styles' => array( 'sow-fas' ), ),
		'tag' => array( 'unicode' => '&#xf02b;', 'styles' => array( 'sow-fas' ), ),
		'tags' => array( 'unicode' => '&#xf02c;', 'styles' => array( 'sow-fas' ), ),
		'tape' => array( 'unicode' => '&#xf4db;', 'styles' => array( 'sow-fas' ), ),
		'tasks' => array( 'unicode' => '&#xf0ae;', 'styles' => array( 'sow-fas' ), ),
		'taxi' => array( 'unicode' => '&#xf1ba;', 'styles' => array( 'sow-fas' ), ),
		'teamspeak' => array( 'unicode' => '&#xf4f9;', 'styles' => array( 'sow-fab' ), ),
		'teeth' => array( 'unicode' => '&#xf62e;', 'styles' => array( 'sow-fas' ), ),
		'teeth-open' => array( 'unicode' => '&#xf62f;', 'styles' => array( 'sow-fas' ), ),
		'telegram' => array( 'unicode' => '&#xf2c6;', 'styles' => array( 'sow-fab' ), ),
		'telegram-plane' => array( 'unicode' => '&#xf3fe;', 'styles' => array( 'sow-fab' ), ),
		'temperature-high' => array( 'unicode' => '&#xf769;', 'styles' => array( 'sow-fas' ), ),
		'temperature-low' => array( 'unicode' => '&#xf76b;', 'styles' => array( 'sow-fas' ), ),
		'tencent-weibo' => array( 'unicode' => '&#xf1d5;', 'styles' => array( 'sow-fab' ), ),
		'tenge' => array( 'unicode' => '&#xf7d7;', 'styles' => array( 'sow-fas' ), ),
		'terminal' => array( 'unicode' => '&#xf120;', 'styles' => array( 'sow-fas' ), ),
		'text-height' => array( 'unicode' => '&#xf034;', 'styles' => array( 'sow-fas' ), ),
		'text-width' => array( 'unicode' => '&#xf035;', 'styles' => array( 'sow-fas' ), ),
		'th' => array( 'unicode' => '&#xf00a;', 'styles' => array( 'sow-fas' ), ),
		'th-large' => array( 'unicode' => '&#xf009;', 'styles' => array( 'sow-fas' ), ),
		'th-list' => array( 'unicode' => '&#xf00b;', 'styles' => array( 'sow-fas' ), ),
		'the-red-yeti' => array( 'unicode' => '&#xf69d;', 'styles' => array( 'sow-fab' ), ),
		'theater-masks' => array( 'unicode' => '&#xf630;', 'styles' => array( 'sow-fas' ), ),
		'themeco' => array( 'unicode' => '&#xf5c6;', 'styles' => array( 'sow-fab' ), ),
		'themeisle' => array( 'unicode' => '&#xf2b2;', 'styles' => array( 'sow-fab' ), ),
		'thermometer' => array( 'unicode' => '&#xf491;', 'styles' => array( 'sow-fas' ), ),
		'thermometer-empty' => array( 'unicode' => '&#xf2cb;', 'styles' => array( 'sow-fas' ), ),
		'thermometer-full' => array( 'unicode' => '&#xf2c7;', 'styles' => array( 'sow-fas' ), ),
		'thermometer-half' => array( 'unicode' => '&#xf2c9;', 'styles' => array( 'sow-fas' ), ),
		'thermometer-quarter' => array( 'unicode' => '&#xf2ca;', 'styles' => array( 'sow-fas' ), ),
		'thermometer-three-quarters' => array( 'unicode' => '&#xf2c8;', 'styles' => array( 'sow-fas' ), ),
		'think-peaks' => array( 'unicode' => '&#xf731;', 'styles' => array( 'sow-fab' ), ),
		'thumbs-down' => array( 'unicode' => '&#xf165;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'thumbs-up' => array( 'unicode' => '&#xf164;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'thumbtack' => array( 'unicode' => '&#xf08d;', 'styles' => array( 'sow-fas' ), ),
		'ticket-alt' => array( 'unicode' => '&#xf3ff;', 'styles' => array( 'sow-fas' ), ),
		'tiktok' => array( 'unicode' => '&#xe07b;', 'styles' => array( 'sow-fab' ), ),
		'times' => array( 'unicode' => '&#xf00d;', 'styles' => array( 'sow-fas' ), ),
		'times-circle' => array( 'unicode' => '&#xf057;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'tint' => array( 'unicode' => '&#xf043;', 'styles' => array( 'sow-fas' ), ),
		'tint-slash' => array( 'unicode' => '&#xf5c7;', 'styles' => array( 'sow-fas' ), ),
		'tired' => array( 'unicode' => '&#xf5c8;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'toggle-off' => array( 'unicode' => '&#xf204;', 'styles' => array( 'sow-fas' ), ),
		'toggle-on' => array( 'unicode' => '&#xf205;', 'styles' => array( 'sow-fas' ), ),
		'toilet' => array( 'unicode' => '&#xf7d8;', 'styles' => array( 'sow-fas' ), ),
		'toilet-paper' => array( 'unicode' => '&#xf71e;', 'styles' => array( 'sow-fas' ), ),
		'toilet-paper-slash' => array( 'unicode' => '&#xe072;', 'styles' => array( 'sow-fas' ), ),
		'toolbox' => array( 'unicode' => '&#xf552;', 'styles' => array( 'sow-fas' ), ),
		'tools' => array( 'unicode' => '&#xf7d9;', 'styles' => array( 'sow-fas' ), ),
		'tooth' => array( 'unicode' => '&#xf5c9;', 'styles' => array( 'sow-fas' ), ),
		'torah' => array( 'unicode' => '&#xf6a0;', 'styles' => array( 'sow-fas' ), ),
		'torii-gate' => array( 'unicode' => '&#xf6a1;', 'styles' => array( 'sow-fas' ), ),
		'tractor' => array( 'unicode' => '&#xf722;', 'styles' => array( 'sow-fas' ), ),
		'trade-federation' => array( 'unicode' => '&#xf513;', 'styles' => array( 'sow-fab' ), ),
		'trademark' => array( 'unicode' => '&#xf25c;', 'styles' => array( 'sow-fas' ), ),
		'traffic-light' => array( 'unicode' => '&#xf637;', 'styles' => array( 'sow-fas' ), ),
		'trailer' => array( 'unicode' => '&#xe041;', 'styles' => array( 'sow-fas' ), ),
		'train' => array( 'unicode' => '&#xf238;', 'styles' => array( 'sow-fas' ), ),
		'tram' => array( 'unicode' => '&#xf7da;', 'styles' => array( 'sow-fas' ), ),
		'transgender' => array( 'unicode' => '&#xf224;', 'styles' => array( 'sow-fas' ), ),
		'transgender-alt' => array( 'unicode' => '&#xf225;', 'styles' => array( 'sow-fas' ), ),
		'trash' => array( 'unicode' => '&#xf1f8;', 'styles' => array( 'sow-fas' ), ),
		'trash-alt' => array( 'unicode' => '&#xf2ed;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'trash-restore' => array( 'unicode' => '&#xf829;', 'styles' => array( 'sow-fas' ), ),
		'trash-restore-alt' => array( 'unicode' => '&#xf82a;', 'styles' => array( 'sow-fas' ), ),
		'tree' => array( 'unicode' => '&#xf1bb;', 'styles' => array( 'sow-fas' ), ),
		'trello' => array( 'unicode' => '&#xf181;', 'styles' => array( 'sow-fab' ), ),
		'tripadvisor' => array( 'unicode' => '&#xf262;', 'styles' => array( 'sow-fab' ), ),
		'trophy' => array( 'unicode' => '&#xf091;', 'styles' => array( 'sow-fas' ), ),
		'truck' => array( 'unicode' => '&#xf0d1;', 'styles' => array( 'sow-fas' ), ),
		'truck-loading' => array( 'unicode' => '&#xf4de;', 'styles' => array( 'sow-fas' ), ),
		'truck-monster' => array( 'unicode' => '&#xf63b;', 'styles' => array( 'sow-fas' ), ),
		'truck-moving' => array( 'unicode' => '&#xf4df;', 'styles' => array( 'sow-fas' ), ),
		'truck-pickup' => array( 'unicode' => '&#xf63c;', 'styles' => array( 'sow-fas' ), ),
		'tshirt' => array( 'unicode' => '&#xf553;', 'styles' => array( 'sow-fas' ), ),
		'tty' => array( 'unicode' => '&#xf1e4;', 'styles' => array( 'sow-fas' ), ),
		'tumblr' => array( 'unicode' => '&#xf173;', 'styles' => array( 'sow-fab' ), ),
		'tumblr-square' => array( 'unicode' => '&#xf174;', 'styles' => array( 'sow-fab' ), ),
		'tv' => array( 'unicode' => '&#xf26c;', 'styles' => array( 'sow-fas' ), ),
		'twitch' => array( 'unicode' => '&#xf1e8;', 'styles' => array( 'sow-fab' ), ),
		'twitter' => array( 'unicode' => '&#xf099;', 'styles' => array( 'sow-fab' ), ),
		'twitter-square' => array( 'unicode' => '&#xf081;', 'styles' => array( 'sow-fab' ), ),
		'typo3' => array( 'unicode' => '&#xf42b;', 'styles' => array( 'sow-fab' ), ),
		'uber' => array( 'unicode' => '&#xf402;', 'styles' => array( 'sow-fab' ), ),
		'ubuntu' => array( 'unicode' => '&#xf7df;', 'styles' => array( 'sow-fab' ), ),
		'uikit' => array( 'unicode' => '&#xf403;', 'styles' => array( 'sow-fab' ), ),
		'umbraco' => array( 'unicode' => '&#xf8e8;', 'styles' => array( 'sow-fab' ), ),
		'umbrella' => array( 'unicode' => '&#xf0e9;', 'styles' => array( 'sow-fas' ), ),
		'umbrella-beach' => array( 'unicode' => '&#xf5ca;', 'styles' => array( 'sow-fas' ), ),
		'uncharted' => array( 'unicode' => '&#xe084;', 'styles' => array( 'sow-fab' ), ),
		'underline' => array( 'unicode' => '&#xf0cd;', 'styles' => array( 'sow-fas' ), ),
		'undo' => array( 'unicode' => '&#xf0e2;', 'styles' => array( 'sow-fas' ), ),
		'undo-alt' => array( 'unicode' => '&#xf2ea;', 'styles' => array( 'sow-fas' ), ),
		'uniregistry' => array( 'unicode' => '&#xf404;', 'styles' => array( 'sow-fab' ), ),
		'unity' => array( 'unicode' => '&#xe049;', 'styles' => array( 'sow-fab' ), ),
		'universal-access' => array( 'unicode' => '&#xf29a;', 'styles' => array( 'sow-fas' ), ),
		'university' => array( 'unicode' => '&#xf19c;', 'styles' => array( 'sow-fas' ), ),
		'unlink' => array( 'unicode' => '&#xf127;', 'styles' => array( 'sow-fas' ), ),
		'unlock' => array( 'unicode' => '&#xf09c;', 'styles' => array( 'sow-fas' ), ),
		'unlock-alt' => array( 'unicode' => '&#xf13e;', 'styles' => array( 'sow-fas' ), ),
		'unsplash' => array( 'unicode' => '&#xe07c;', 'styles' => array( 'sow-fab' ), ),
		'untappd' => array( 'unicode' => '&#xf405;', 'styles' => array( 'sow-fab' ), ),
		'upload' => array( 'unicode' => '&#xf093;', 'styles' => array( 'sow-fas' ), ),
		'ups' => array( 'unicode' => '&#xf7e0;', 'styles' => array( 'sow-fab' ), ),
		'usb' => array( 'unicode' => '&#xf287;', 'styles' => array( 'sow-fab' ), ),
		'user' => array( 'unicode' => '&#xf007;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'user-alt' => array( 'unicode' => '&#xf406;', 'styles' => array( 'sow-fas' ), ),
		'user-alt-slash' => array( 'unicode' => '&#xf4fa;', 'styles' => array( 'sow-fas' ), ),
		'user-astronaut' => array( 'unicode' => '&#xf4fb;', 'styles' => array( 'sow-fas' ), ),
		'user-check' => array( 'unicode' => '&#xf4fc;', 'styles' => array( 'sow-fas' ), ),
		'user-circle' => array( 'unicode' => '&#xf2bd;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'user-clock' => array( 'unicode' => '&#xf4fd;', 'styles' => array( 'sow-fas' ), ),
		'user-cog' => array( 'unicode' => '&#xf4fe;', 'styles' => array( 'sow-fas' ), ),
		'user-edit' => array( 'unicode' => '&#xf4ff;', 'styles' => array( 'sow-fas' ), ),
		'user-friends' => array( 'unicode' => '&#xf500;', 'styles' => array( 'sow-fas' ), ),
		'user-graduate' => array( 'unicode' => '&#xf501;', 'styles' => array( 'sow-fas' ), ),
		'user-injured' => array( 'unicode' => '&#xf728;', 'styles' => array( 'sow-fas' ), ),
		'user-lock' => array( 'unicode' => '&#xf502;', 'styles' => array( 'sow-fas' ), ),
		'user-md' => array( 'unicode' => '&#xf0f0;', 'styles' => array( 'sow-fas' ), ),
		'user-minus' => array( 'unicode' => '&#xf503;', 'styles' => array( 'sow-fas' ), ),
		'user-ninja' => array( 'unicode' => '&#xf504;', 'styles' => array( 'sow-fas' ), ),
		'user-nurse' => array( 'unicode' => '&#xf82f;', 'styles' => array( 'sow-fas' ), ),
		'user-plus' => array( 'unicode' => '&#xf234;', 'styles' => array( 'sow-fas' ), ),
		'user-secret' => array( 'unicode' => '&#xf21b;', 'styles' => array( 'sow-fas' ), ),
		'user-shield' => array( 'unicode' => '&#xf505;', 'styles' => array( 'sow-fas' ), ),
		'user-slash' => array( 'unicode' => '&#xf506;', 'styles' => array( 'sow-fas' ), ),
		'user-tag' => array( 'unicode' => '&#xf507;', 'styles' => array( 'sow-fas' ), ),
		'user-tie' => array( 'unicode' => '&#xf508;', 'styles' => array( 'sow-fas' ), ),
		'user-times' => array( 'unicode' => '&#xf235;', 'styles' => array( 'sow-fas' ), ),
		'users' => array( 'unicode' => '&#xf0c0;', 'styles' => array( 'sow-fas' ), ),
		'users-cog' => array( 'unicode' => '&#xf509;', 'styles' => array( 'sow-fas' ), ),
		'users-slash' => array( 'unicode' => '&#xe073;', 'styles' => array( 'sow-fas' ), ),
		'usps' => array( 'unicode' => '&#xf7e1;', 'styles' => array( 'sow-fab' ), ),
		'ussunnah' => array( 'unicode' => '&#xf407;', 'styles' => array( 'sow-fab' ), ),
		'utensil-spoon' => array( 'unicode' => '&#xf2e5;', 'styles' => array( 'sow-fas' ), ),
		'utensils' => array( 'unicode' => '&#xf2e7;', 'styles' => array( 'sow-fas' ), ),
		'vaadin' => array( 'unicode' => '&#xf408;', 'styles' => array( 'sow-fab' ), ),
		'vector-square' => array( 'unicode' => '&#xf5cb;', 'styles' => array( 'sow-fas' ), ),
		'venus' => array( 'unicode' => '&#xf221;', 'styles' => array( 'sow-fas' ), ),
		'venus-double' => array( 'unicode' => '&#xf226;', 'styles' => array( 'sow-fas' ), ),
		'venus-mars' => array( 'unicode' => '&#xf228;', 'styles' => array( 'sow-fas' ), ),
		'vest' => array( 'unicode' => '&#xe085;', 'styles' => array( 'sow-fas' ), ),
		'vest-patches' => array( 'unicode' => '&#xe086;', 'styles' => array( 'sow-fas' ), ),
		'viacoin' => array( 'unicode' => '&#xf237;', 'styles' => array( 'sow-fab' ), ),
		'viadeo' => array( 'unicode' => '&#xf2a9;', 'styles' => array( 'sow-fab' ), ),
		'viadeo-square' => array( 'unicode' => '&#xf2aa;', 'styles' => array( 'sow-fab' ), ),
		'vial' => array( 'unicode' => '&#xf492;', 'styles' => array( 'sow-fas' ), ),
		'vials' => array( 'unicode' => '&#xf493;', 'styles' => array( 'sow-fas' ), ),
		'viber' => array( 'unicode' => '&#xf409;', 'styles' => array( 'sow-fab' ), ),
		'video' => array( 'unicode' => '&#xf03d;', 'styles' => array( 'sow-fas' ), ),
		'video-slash' => array( 'unicode' => '&#xf4e2;', 'styles' => array( 'sow-fas' ), ),
		'vihara' => array( 'unicode' => '&#xf6a7;', 'styles' => array( 'sow-fas' ), ),
		'vimeo' => array( 'unicode' => '&#xf40a;', 'styles' => array( 'sow-fab' ), ),
		'vimeo-square' => array( 'unicode' => '&#xf194;', 'styles' => array( 'sow-fab' ), ),
		'vimeo-v' => array( 'unicode' => '&#xf27d;', 'styles' => array( 'sow-fab' ), ),
		'vine' => array( 'unicode' => '&#xf1ca;', 'styles' => array( 'sow-fab' ), ),
		'virus' => array( 'unicode' => '&#xe074;', 'styles' => array( 'sow-fas' ), ),
		'virus-slash' => array( 'unicode' => '&#xe075;', 'styles' => array( 'sow-fas' ), ),
		'viruses' => array( 'unicode' => '&#xe076;', 'styles' => array( 'sow-fas' ), ),
		'vk' => array( 'unicode' => '&#xf189;', 'styles' => array( 'sow-fab' ), ),
		'vnv' => array( 'unicode' => '&#xf40b;', 'styles' => array( 'sow-fab' ), ),
		'voicemail' => array( 'unicode' => '&#xf897;', 'styles' => array( 'sow-fas' ), ),
		'volleyball-ball' => array( 'unicode' => '&#xf45f;', 'styles' => array( 'sow-fas' ), ),
		'volume-down' => array( 'unicode' => '&#xf027;', 'styles' => array( 'sow-fas' ), ),
		'volume-mute' => array( 'unicode' => '&#xf6a9;', 'styles' => array( 'sow-fas' ), ),
		'volume-off' => array( 'unicode' => '&#xf026;', 'styles' => array( 'sow-fas' ), ),
		'volume-up' => array( 'unicode' => '&#xf028;', 'styles' => array( 'sow-fas' ), ),
		'vote-yea' => array( 'unicode' => '&#xf772;', 'styles' => array( 'sow-fas' ), ),
		'vr-cardboard' => array( 'unicode' => '&#xf729;', 'styles' => array( 'sow-fas' ), ),
		'vuejs' => array( 'unicode' => '&#xf41f;', 'styles' => array( 'sow-fab' ), ),
		'walking' => array( 'unicode' => '&#xf554;', 'styles' => array( 'sow-fas' ), ),
		'wallet' => array( 'unicode' => '&#xf555;', 'styles' => array( 'sow-fas' ), ),
		'warehouse' => array( 'unicode' => '&#xf494;', 'styles' => array( 'sow-fas' ), ),
		'watchman-monitoring' => array( 'unicode' => '&#xe087;', 'styles' => array( 'sow-fab' ), ),
		'water' => array( 'unicode' => '&#xf773;', 'styles' => array( 'sow-fas' ), ),
		'wave-square' => array( 'unicode' => '&#xf83e;', 'styles' => array( 'sow-fas' ), ),
		'waze' => array( 'unicode' => '&#xf83f;', 'styles' => array( 'sow-fab' ), ),
		'weebly' => array( 'unicode' => '&#xf5cc;', 'styles' => array( 'sow-fab' ), ),
		'weibo' => array( 'unicode' => '&#xf18a;', 'styles' => array( 'sow-fab' ), ),
		'weight' => array( 'unicode' => '&#xf496;', 'styles' => array( 'sow-fas' ), ),
		'weight-hanging' => array( 'unicode' => '&#xf5cd;', 'styles' => array( 'sow-fas' ), ),
		'weixin' => array( 'unicode' => '&#xf1d7;', 'styles' => array( 'sow-fab' ), ),
		'whatsapp' => array( 'unicode' => '&#xf232;', 'styles' => array( 'sow-fab' ), ),
		'whatsapp-square' => array( 'unicode' => '&#xf40c;', 'styles' => array( 'sow-fab' ), ),
		'wheelchair' => array( 'unicode' => '&#xf193;', 'styles' => array( 'sow-fas' ), ),
		'whmcs' => array( 'unicode' => '&#xf40d;', 'styles' => array( 'sow-fab' ), ),
		'wifi' => array( 'unicode' => '&#xf1eb;', 'styles' => array( 'sow-fas' ), ),
		'wikipedia-w' => array( 'unicode' => '&#xf266;', 'styles' => array( 'sow-fab' ), ),
		'wind' => array( 'unicode' => '&#xf72e;', 'styles' => array( 'sow-fas' ), ),
		'window-close' => array( 'unicode' => '&#xf410;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'window-maximize' => array( 'unicode' => '&#xf2d0;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'window-minimize' => array( 'unicode' => '&#xf2d1;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'window-restore' => array( 'unicode' => '&#xf2d2;', 'styles' => array( 'sow-fas', 'sow-far' ), ),
		'windows' => array( 'unicode' => '&#xf17a;', 'styles' => array( 'sow-fab' ), ),
		'wine-bottle' => array( 'unicode' => '&#xf72f;', 'styles' => array( 'sow-fas' ), ),
		'wine-glass' => array( 'unicode' => '&#xf4e3;', 'styles' => array( 'sow-fas' ), ),
		'wine-glass-alt' => array( 'unicode' => '&#xf5ce;', 'styles' => array( 'sow-fas' ), ),
		'wix' => array( 'unicode' => '&#xf5cf;', 'styles' => array( 'sow-fab' ), ),
		'wizards-of-the-coast' => array( 'unicode' => '&#xf730;', 'styles' => array( 'sow-fab' ), ),
		'wodu' => array( 'unicode' => '&#xe088;', 'styles' => array( 'sow-fab' ), ),
		'wolf-pack-battalion' => array( 'unicode' => '&#xf514;', 'styles' => array( 'sow-fab' ), ),
		'won-sign' => array( 'unicode' => '&#xf159;', 'styles' => array( 'sow-fas' ), ),
		'wordpress' => array( 'unicode' => '&#xf19a;', 'styles' => array( 'sow-fab' ), ),
		'wordpress-simple' => array( 'unicode' => '&#xf411;', 'styles' => array( 'sow-fab' ), ),
		'wpbeginner' => array( 'unicode' => '&#xf297;', 'styles' => array( 'sow-fab' ), ),
		'wpexplorer' => array( 'unicode' => '&#xf2de;', 'styles' => array( 'sow-fab' ), ),
		'wpforms' => array( 'unicode' => '&#xf298;', 'styles' => array( 'sow-fab' ), ),
		'wpressr' => array( 'unicode' => '&#xf3e4;', 'styles' => array( 'sow-fab' ), ),
		'wrench' => array( 'unicode' => '&#xf0ad;', 'styles' => array( 'sow-fas' ), ),
		'x-ray' => array( 'unicode' => '&#xf497;', 'styles' => array( 'sow-fas' ), ),
		'xbox' => array( 'unicode' => '&#xf412;', 'styles' => array( 'sow-fab' ), ),
		'xing' => array( 'unicode' => '&#xf168;', 'styles' => array( 'sow-fab' ), ),
		'xing-square' => array( 'unicode' => '&#xf169;', 'styles' => array( 'sow-fab' ), ),
		'y-combinator' => array( 'unicode' => '&#xf23b;', 'styles' => array( 'sow-fab' ), ),
		'yahoo' => array( 'unicode' => '&#xf19e;', 'styles' => array( 'sow-fab' ), ),
		'yammer' => array( 'unicode' => '&#xf840;', 'styles' => array( 'sow-fab' ), ),
		'yandex' => array( 'unicode' => '&#xf413;', 'styles' => array( 'sow-fab' ), ),
		'yandex-international' => array( 'unicode' => '&#xf414;', 'styles' => array( 'sow-fab' ), ),
		'yarn' => array( 'unicode' => '&#xf7e3;', 'styles' => array( 'sow-fab' ), ),
		'yelp' => array( 'unicode' => '&#xf1e9;', 'styles' => array( 'sow-fab' ), ),
		'yen-sign' => array( 'unicode' => '&#xf157;', 'styles' => array( 'sow-fas' ), ),
		'yin-yang' => array( 'unicode' => '&#xf6ad;', 'styles' => array( 'sow-fas' ), ),
		'yoast' => array( 'unicode' => '&#xf2b1;', 'styles' => array( 'sow-fab' ), ),
		'youtube' => array( 'unicode' => '&#xf167;', 'styles' => array( 'sow-fab' ), ),
		'youtube-square' => array( 'unicode' => '&#xf431;', 'styles' => array( 'sow-fab' ), ),
		'zhihu' => array( 'unicode' => '&#xf63f;', 'styles' => array( 'sow-fab' ), ),

	));
}
add_filter('siteorigin_widgets_icons_fontawesome', 'siteorigin_widgets_icons_fontawesome_filter');

function siteorigin_widgets_icon_styles_fontawesome_filter( $styles ) {
    return array_merge( $styles, array(
        'sow-far' => __( 'Regular', 'so-widgets-bundle' ),
        'sow-fas' => __( 'Solid', 'so-widgets-bundle' ),
        'sow-fab' => __( 'Brands', 'so-widgets-bundle' ),
    ) );
}

add_filter('siteorigin_widgets_icon_styles_fontawesome', 'siteorigin_widgets_icon_styles_fontawesome_filter');

function siteorigin_widgets_icon_migrate_fontawesome( $icon_data ) {
	
	// Previous versions of FontAwesome didn't use 'style'.
	if ( ! empty( $icon_data ) && ! isset( $icon_data['style'] ) ) {
		
		$name_map = siteorigin_widgets_icon_migrate_fontawesome_name_map();
		
		if ( isset( $name_map[ $icon_data['icon'] ] ) ) {
			if ( preg_match( '/\-o\b/', $icon_data['icon'] ) ) {
				$icon_data['style'] = 'sow-far';
			}
			$icon_data['icon'] = $name_map[ $icon_data['icon'] ];
		}
		if ( empty( $icon_data['style'] ) ) {
			$icons = apply_filters( 'siteorigin_widgets_icons_fontawesome', array() );
			if ( ! empty( $icons[ $icon_data['icon'] ] ) && ! empty( $icons[ $icon_data['icon'] ]['styles'] ) ) {
				$icon_data['style'] = $icons[ $icon_data['icon'] ]['styles'][0];
			} else {
				$icon_data['style'] = 'sow-fas';
			}
		}
	}
	return $icon_data;
}

add_filter( 'siteorigin_widgets_icon_migrate_fontawesome', 'siteorigin_widgets_icon_migrate_fontawesome' );

function siteorigin_widgets_icon_migrate_fontawesome_name_map() {
	return array(
		'address-book-o' => 'address-book',
		'address-card-o' => 'address-card',
		'area-chart' => 'chart-area',
		'arrow-circle-o-down' => 'arrow-alt-circle-down',
		'arrow-circle-o-left' => 'arrow-alt-circle-left',
		'arrow-circle-o-right' => 'arrow-alt-circle-right',
		'arrow-circle-o-up' => 'arrow-alt-circle-up',
		'arrows' => 'arrows-alt',
		'arrows-alt' => 'expand-arrows-alt',
		'arrows-h' => 'arrows-alt-h',
		'arrows-v' => 'arrows-alt-v',
		'asl-interpreting' => 'american-sign-language-interpreting',
		'automobile' => 'car',
		'bank' => 'university',
		'bar-chart' => 'chart-bar',
		'bar-chart-o' => 'chart-bar',
		'bathtub' => 'bath',
		'battery' => 'battery-full',
		'battery-0' => 'battery-empty',
		'battery-1' => 'battery-quarter',
		'battery-2' => 'battery-half',
		'battery-3' => 'battery-three-quarters',
		'battery-4' => 'battery-full',
		'bell-o' => 'bell',
		'bell-slash-o' => 'bell-slash',
		'bitbucket-square' => 'bitbucket',
		'bitcoin' => 'btc',
		'bookmark-o' => 'bookmark',
		'building-o' => 'building',
		'cab' => 'taxi',
		'calendar' => 'calendar-alt',
		'calendar-check-o' => 'calendar-check',
		'calendar-minus-o' => 'calendar-minus',
		'calendar-o' => 'calendar',
		'calendar-plus-o' => 'calendar-plus',
		'calendar-times-o' => 'calendar-times',
		'caret-square-o-down' => 'caret-square-down',
		'caret-square-o-left' => 'caret-square-left',
		'caret-square-o-right' => 'caret-square-right',
		'caret-square-o-up' => 'caret-square-up',
		'cc' => 'closed-captioning',
		'chain' => 'link',
		'chain-broken' => 'unlink',
		'check-circle-o' => 'check-circle',
		'check-square-o' => 'check-square',
		'circle-o' => 'circle',
		'circle-o-notch' => 'circle-notch',
		'circle-thin' => 'circle',
		'clock-o' => 'clock',
		'close' => 'times',
		'cloud-download' => 'cloud-download-alt',
		'cloud-upload' => 'cloud-upload-alt',
		'cny' => 'yen-sign',
		'code-fork' => 'code-branch',
		'comment-o' => 'comment',
		'commenting' => 'comment-dots',
		'commenting-o' => 'comment-dots',
		'comments-o' => 'comments',
		'credit-card-alt' => 'credit-card',
		'cutlery' => 'utensils',
		'dashboard' => 'tachometer-alt',
		'deafness' => 'deaf',
		'dedent' => 'outdent',
		'diamond' => 'gem',
		'dollar' => 'dollar-sign',
		'dot-circle-o' => 'dot-circle',
		'drivers-license' => 'id-card',
		'drivers-license-o' => 'id-card',
		'eercast' => 'sellcast',
		'envelope-o' => 'envelope',
		'envelope-open-o' => 'envelope-open',
		'eur' => 'euro-sign',
		'euro' => 'euro-sign',
		'exchange' => 'exchange-alt',
		'external-link' => 'external-link-alt',
		'external-link-square' => 'external-link-square-alt',
		'eyedropper' => 'eye-dropper',
		'fa' => 'font-awesome',
		'facebook' => 'facebook-f',
		'facebook-official' => 'facebook',
		'feed' => 'rss',
		'file-archive-o' => 'file-archive',
		'file-audio-o' => 'file-audio',
		'file-code-o' => 'file-code',
		'file-excel-o' => 'file-excel',
		'file-image-o' => 'file-image',
		'file-movie-o' => 'file-video',
		'file-o' => 'file',
		'file-pdf-o' => 'file-pdf',
		'file-photo-o' => 'file-image',
		'file-picture-o' => 'file-image',
		'file-powerpoint-o' => 'file-powerpoint',
		'file-sound-o' => 'file-audio',
		'file-text' => 'file-alt',
		'file-text-o' => 'file-alt',
		'file-video-o' => 'file-video',
		'file-word-o' => 'file-word',
		'file-zip-o' => 'file-archive',
		'files-o' => 'copy',
		'flag-o' => 'flag',
		'flash' => 'bolt',
		'floppy-o' => 'save',
		'folder-o' => 'folder',
		'folder-open-o' => 'folder-open',
		'frown-o' => 'frown',
		'futbol-o' => 'futbol',
		'gbp' => 'pound-sign',
		'ge' => 'empire',
		'gear' => 'cog',
		'gears' => 'cogs',
		'gittip' => 'gratipay',
		'glass' => 'glass-martini',
		'google-plus' => 'google-plus-g',
		'google-plus-circle' => 'google-plus',
		'google-plus-official' => 'google-plus',
		'google-plus-square' => 'google-plus-square',
		'group' => 'users',
		'hand-grab-o' => 'hand-rock',
		'hand-lizard-o' => 'hand-lizard',
		'hand-o-down' => 'hand-point-down',
		'hand-o-left' => 'hand-point-left',
		'hand-o-right' => 'hand-point-right',
		'hand-o-up' => 'hand-point-up',
		'hand-paper-o' => 'hand-paper',
		'hand-peace-o' => 'hand-peace',
		'hand-pointer-o' => 'hand-pointer',
		'hand-rock-o' => 'hand-rock',
		'hand-scissors-o' => 'hand-scissors',
		'hand-spock-o' => 'hand-spock',
		'hand-stop-o' => 'hand-paper',
		'handshake-o' => 'handshake',
		'hard-of-hearing' => 'deaf',
		'haykal' => 'bahai',
		'hdd-o' => 'hdd',
		'header' => 'heading',
		'heart-o' => 'heart',
		'hospital-o' => 'hospital',
		'hotel' => 'bed',
		'hourglass-1' => 'hourglass-start',
		'hourglass-2' => 'hourglass-half',
		'hourglass-3' => 'hourglass-end',
		'hourglass-o' => 'hourglass',
		'id-card-o' => 'id-card',
		'ils' => 'shekel-sign',
		'inr' => 'rupee-sign',
		'institution' => 'university',
		'intersex' => 'transgender',
		'jpy' => 'yen-sign',
		'keyboard-o' => 'keyboard',
		'krw' => 'won-sign',
		'legal' => 'gavel',
		'lemon-o' => 'lemon',
		'level-down' => 'level-down-alt',
		'level-up' => 'level-up-alt',
		'life-bouy' => 'life-ring',
		'life-buoy' => 'life-ring',
		'life-saver' => 'life-ring',
		'lightbulb-o' => 'lightbulb',
		'line-chart' => 'chart-line',
		'linkedin' => 'linkedin-in',
		'linkedin-square' => 'linkedin',
		'long-arrow-down' => 'long-arrow-alt-down',
		'long-arrow-left' => 'long-arrow-alt-left',
		'long-arrow-right' => 'long-arrow-alt-right',
		'long-arrow-up' => 'long-arrow-alt-up',
		'mail-forward' => 'share',
		'mail-reply' => 'reply',
		'mail-reply-all' => 'reply-all',
		'map-marker' => 'map-marker-alt',
		'map-o' => 'map',
		'meanpath' => 'font-awesome',
		'meh-o' => 'meh',
		'minus-square-o' => 'minus-square',
		'mobile' => 'mobile-alt',
		'mobile-phone' => 'mobile-alt',
		'money' => 'money-bill-alt',
		'moon-o' => 'moon',
		'mortar-board' => 'graduation-cap',
		'navicon' => 'bars',
		'newspaper-o' => 'newspaper',
		'paper-plane-o' => 'paper-plane',
		'paste' => 'clipboard',
		'pause-circle-o' => 'pause-circle',
		'pencil' => 'pencil-alt',
		'pencil-square' => 'pen-square',
		'pencil-square-o' => 'edit',
		'photo' => 'image',
		'picture-o' => 'image',
		'pie-chart' => 'chart-pie',
		'play-circle-o' => 'play-circle',
		'plus-square-o' => 'plus-square',
		'question-circle-o' => 'question-circle',
		'ra' => 'rebel',
		'refresh' => 'sync',
		'remove' => 'times',
		'reorder' => 'bars',
		'repeat' => 'redo',
		'resistance' => 'rebel',
		'rmb' => 'yen-sign',
		'rotate-left' => 'undo',
		'rotate-right' => 'redo',
		'rouble' => 'ruble-sign',
		'rub' => 'ruble-sign',
		'ruble' => 'ruble-sign',
		'rupee' => 'rupee-sign',
		's15' => 'bath',
		'scissors' => 'cut',
		'send' => 'paper-plane',
		'send-o' => 'paper-plane',
		'share-square-o' => 'share-square',
		'shekel' => 'shekel-sign',
		'sheqel' => 'shekel-sign',
		'shield' => 'shield-alt',
		'sign-in' => 'sign-in-alt',
		'sign-out' => 'sign-out-alt',
		'signing' => 'sign-language',
		'sliders' => 'sliders-h',
		'smile-o' => 'smile',
		'snowflake-o' => 'snowflake',
		'soccer-ball-o' => 'futbol',
		'sort-alpha-asc' => 'sort-alpha-down',
		'sort-alpha-desc' => 'sort-alpha-up',
		'sort-amount-asc' => 'sort-amount-down',
		'sort-amount-desc' => 'sort-amount-up',
		'sort-asc' => 'sort-up',
		'sort-desc' => 'sort-down',
		'sort-numeric-asc' => 'sort-numeric-down',
		'sort-numeric-desc' => 'sort-numeric-up',
		'spoon' => 'utensil-spoon',
		'square-o' => 'square',
		'star-half-empty' => 'star-half',
		'star-half-full' => 'star-half',
		'star-half-o' => 'star-half',
		'star-o' => 'star',
		'sticky-note-o' => 'sticky-note',
		'stop-circle-o' => 'stop-circle',
		'sun-o' => 'sun',
		'support' => 'life-ring',
		'tablet' => 'tablet-alt',
		'tachometer' => 'tachometer-alt',
		'television' => 'tv',
		'thermometer' => 'thermometer-full',
		'thermometer-0' => 'thermometer-empty',
		'thermometer-1' => 'thermometer-quarter',
		'thermometer-2' => 'thermometer-half',
		'thermometer-3' => 'thermometer-three-quarters',
		'thermometer-4' => 'thermometer-full',
		'thumb-tack' => 'thumbtack',
		'thumbs-o-down' => 'thumbs-down',
		'thumbs-o-up' => 'thumbs-up',
		'ticket' => 'ticket-alt',
		'times-circle-o' => 'times-circle',
		'times-rectangle' => 'window-close',
		'times-rectangle-o' => 'window-close',
		'toggle-down' => 'caret-square-down',
		'toggle-left' => 'caret-square-left',
		'toggle-right' => 'caret-square-right',
		'toggle-up' => 'caret-square-up',
		'trash' => 'trash-alt',
		'trash-o' => 'trash-alt',
		'try' => 'lira-sign',
		'turkish-lira' => 'lira-sign',
		'unsorted' => 'sort',
		'usd' => 'dollar-sign',
		'user-circle-o' => 'user-circle',
		'user-o' => 'user',
		'vcard' => 'address-card',
		'vcard-o' => 'address-card',
		'video-camera' => 'video',
		'vimeo' => 'vimeo-v',
		'volume-control-phone' => 'phone-volume',
		'warning' => 'exclamation-triangle',
		'wechat' => 'weixin',
		'wheelchair-alt' => 'accessible-icon',
		'window-close-o' => 'window-close',
		'won' => 'won-sign',
		'y-combinator-square' => 'hacker-news',
		'yc' => 'y-combinator',
		'yc-square' => 'hacker-news',
		'yen' => 'yen-sign',
		'youtube-play' => 'youtube',
		'youtube-square' => 'youtube-square',
	);
}
